@@ -231,7 +231,7 @@ tools = [
 ['imagery_tools', 4, 'IHS Sharpening'],
 ['imagery_tools', 5, 'Colour Normalized Brovey Sharpening'],
 ['imagery_tools', 6, 'Colour Normalized Spectral Sharpening'],
-['imagery_tools', 7, 'Principle Components Based Image Sharpening'],
+['imagery_tools', 7, 'Principal Component Based Image Sharpening'],
 ['imagery_tools', 8, 'Top of Atmosphere Reflectance'],
 ['imagery_tools', 9, 'Automated Cloud Cover Assessment'],
 ['imagery_tools', 10, 'Landsat Import with Options'],
@@ -467,9 +467,9 @@ tools = [
 ['statistics_grid', 5, 'Zonal Grid Statistics'],
 ['statistics_grid', 6, 'Directional Statistics for Single Grid'],
 ['statistics_grid', 7, 'Global Moran\'s I for Grids'],
-['statistics_grid', 8, 'Principle Components Analysis'],
+['statistics_grid', 8, 'Principal Component Analysis'],
 ['statistics_grid', 9, 'Multi-Band Variation'],
-['statistics_grid', 10, 'Inverse Principle Components Rotation'],
+['statistics_grid', 10, 'Inverse Principal Components Rotation'],
 ['statistics_grid', 11, 'Longitudinal Grid Statistics'],
 ['statistics_grid', 12, 'Meridional Grid Statistics'],
 ['statistics_grid', 13, 'Save Grid Statistics to Table'],
@@ -581,7 +581,7 @@ tools = [
 ['table_calculus', 2, 'Field Calculator [Shapes]'],
 ['table_calculus', 5, 'Running Average'],
 ['table_calculus', 6, 'Cluster Analysis'],
-['table_calculus', 7, 'Principle Components Analysis'],
+['table_calculus', 7, 'Principal Component Analysis'],
 ['table_calculus', 8, 'Fill Gaps in Ordered Records'],
 ['table_calculus', 11, 'Find Field of Extreme Value'],
 ['table_calculus', 12, 'Minimum Redundancy Feature Selection'],
@@ -725,5 +725,12 @@ tools = [
 ['statistics_grid', 16, 'Statistics for Grids from Files'],
 ['statistics_grid', 17, 'Build Statistics for Grids'],
 ['statistics_grid', 18, 'Evaluate Statistics for Grids'],
-['table_calculus', 9, 'Fill Gaps in Records']
+['table_calculus', 9, 'Fill Gaps in Records'],
+['pj_proj4', 29, 'Single Coordinate Transformation'],
+['shapes_points', 21, 'Create Random Points'],
+['statistics_grid', 19, 'Add Statistics for Grids'],
+['table_tools', 23, 'Change Field Name'],
+['ta_hydrology', 29, 'Flow Accumulation (Parallelizable)'],
+['table_tools', 24, 'Formatted Text'],
+['table_tools', 25, 'Formatted Text [Shapes]']
 ]
