@@ -200,10 +200,10 @@ SAGA_API_DLL_EXPORT void			SG_Free				(void *memblock);
 //---------------------------------------------------------
 SAGA_API_DLL_EXPORT void			SG_Swap_Bytes		(void *Buffer, int nBytes);
 
-SAGA_API_DLL_EXPORT int				SG_Mem_Get_Int		(const char *Buffer			, bool bSwapBytes);
-SAGA_API_DLL_EXPORT void			SG_Mem_Set_Int		(char *Buffer, int Value	, bool bSwapBytes);
-SAGA_API_DLL_EXPORT double			SG_Mem_Get_Double	(const char *Buffer			, bool bSwapBytes);
-SAGA_API_DLL_EXPORT void			SG_Mem_Set_Double	(char *Buffer, double Value	, bool bSwapBytes);
+SAGA_API_DLL_EXPORT int				SG_Mem_Get_Int		(const char *Buffer        , bool bSwapBytes);
+SAGA_API_DLL_EXPORT void			SG_Mem_Set_Int		(char *Buffer, int Value   , bool bSwapBytes);
+SAGA_API_DLL_EXPORT double			SG_Mem_Get_Double	(const char *Buffer        , bool bSwapBytes);
+SAGA_API_DLL_EXPORT void			SG_Mem_Set_Double	(char *Buffer, double Value, bool bSwapBytes);
 
 
 ///////////////////////////////////////////////////////////
@@ -213,29 +213,16 @@ SAGA_API_DLL_EXPORT void			SG_Mem_Set_Double	(char *Buffer, double Value	, bool
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-#define SG_STR_CMP(s1, s2)		CSG_String(s1).Cmp(s2)
-
-#if !defined(_SAGA_UNICODE)
-	#define SG_Char				char
-	#define SG_T(s)				s
-	#define SG_PRINTF			printf
-	#define SG_FPRINTF			fprintf
-	#define SG_SSCANF			sscanf
-	#define SG_STR_CPY			strcpy
-	#define SG_STR_LEN			strlen
-	#define SG_STR_TOD			strtod
-	#define SG_STR_MBTOSG(s)	s
-#else
-	#define SG_Char				wchar_t
-	#define SG_T(s)				L ## s
-	#define SG_PRINTF			SG_Printf
-	#define SG_FPRINTF			SG_FPrintf
-	#define SG_SSCANF			swscanf
-	#define SG_STR_CPY			wcscpy
-	#define SG_STR_LEN			wcslen
-	#define SG_STR_TOD			wcstod
-	#define SG_STR_MBTOSG(s)	CSG_String(s).w_str()
-#endif
+#define SG_Char				wchar_t
+#define SG_T(s)				L ## s
+#define SG_PRINTF			SG_Printf
+#define SG_FPRINTF			SG_FPrintf
+#define SG_SSCANF			swscanf
+#define SG_STR_CPY			wcscpy
+#define SG_STR_LEN			wcslen
+#define SG_STR_TOD			wcstod
+#define SG_STR_CMP(s1, s2)	CSG_String(s1).Cmp(s2)
+#define SG_STR_MBTOSG(s)	CSG_String(s).w_str()
 
 //---------------------------------------------------------
 class SAGA_API_DLL_EXPORT CSG_String
@@ -318,6 +305,7 @@ public:
 	CSG_String &					Remove				(size_t pos, size_t len);
 
 	int								Trim				(bool fromRight = false);
+	int								Trim_Both			(void);
 
 	int								Find				(char    Character, bool fromEnd = false)	const;
 	int								Find				(wchar_t Character, bool fromEnd = false)	const;
@@ -414,7 +402,7 @@ class SAGA_API_DLL_EXPORT CSG_String_Tokenizer
 {
 public:
 	CSG_String_Tokenizer(void);
-	CSG_String_Tokenizer(const CSG_String &String, const CSG_String &Delimiters=SG_DEFAULT_DELIMITERS, TSG_String_Tokenizer_Mode Mode=SG_TOKEN_DEFAULT);
+	CSG_String_Tokenizer(const CSG_String &String, const CSG_String &Delimiters = SG_DEFAULT_DELIMITERS, TSG_String_Tokenizer_Mode Mode = SG_TOKEN_DEFAULT);
 
 	~CSG_String_Tokenizer(void);
 
@@ -425,7 +413,7 @@ public:
 	size_t							Get_Position		(void)	const;
 	CSG_String						Get_String			(void)	const;
 	bool							Has_More_Tokens		(void)	const;
-	void							Set_String			(const CSG_String &String, const CSG_String &Delimiters=SG_DEFAULT_DELIMITERS, TSG_String_Tokenizer_Mode Mode=SG_TOKEN_DEFAULT);
+	void							Set_String			(const CSG_String &String, const CSG_String &Delimiters = SG_DEFAULT_DELIMITERS, TSG_String_Tokenizer_Mode Mode = SG_TOKEN_DEFAULT);
 
 
 private:
@@ -434,11 +422,19 @@ private:
 
 };
 
+//---------------------------------------------------------
+SAGA_API_DLL_EXPORT CSG_Strings		SG_String_Tokenize				(const CSG_String &String, const CSG_String &Delimiters = SG_DEFAULT_DELIMITERS, TSG_String_Tokenizer_Mode Mode = SG_TOKEN_DEFAULT);
+
 //---------------------------------------------------------
 SAGA_API_DLL_EXPORT bool			SG_is_Character_Numeric			(int Character);
 
-SAGA_API_DLL_EXPORT int				SG_Printf						(const SG_Char *Format, ...);
-SAGA_API_DLL_EXPORT int				SG_FPrintf						(FILE* stream, const SG_Char *Format, ...);
+SAGA_API_DLL_EXPORT int				SG_Printf						(const CSG_String &String);
+SAGA_API_DLL_EXPORT int				SG_Printf						(const  char   *Format, ...);
+SAGA_API_DLL_EXPORT int				SG_Printf						(const wchar_t *Format, ...);
+
+SAGA_API_DLL_EXPORT int				SG_FPrintf						(FILE *Stream, const CSG_String &String);
+SAGA_API_DLL_EXPORT int				SG_FPrintf						(FILE *Stream, const  char   *Format, ...);
+SAGA_API_DLL_EXPORT int				SG_FPrintf						(FILE *Stream, const wchar_t *Format, ...);
 
 SAGA_API_DLL_EXPORT CSG_String		SG_Get_CurrentTimeStr			(bool bWithDate = true);
 
@@ -1448,15 +1444,15 @@ TSG_UI_Callback_ID;
 class SAGA_API_DLL_EXPORT CSG_UI_Parameter
 {
 public:
-	CSG_UI_Parameter(void)						: True(false), Number( 0.0 ), Pointer(NULL)		{}
-	CSG_UI_Parameter(bool              Value)	: True(Value), Number( 0.0 ), Pointer(NULL)		{}
-	CSG_UI_Parameter(int               Value)	: True(false), Number(Value), Pointer(NULL)		{}
-	CSG_UI_Parameter(double            Value)	: True(false), Number(Value), Pointer(NULL)		{}
-	CSG_UI_Parameter(const CSG_String &Value)	: True(false), Number( 0.0 ), Pointer(NULL), String(Value)	{}
-	CSG_UI_Parameter(void             *Value)	: True(false), Number( 0.0 ), Pointer(Value)	{}
+	CSG_UI_Parameter(void)						: Boolean(false), Number( 0.0 ), Pointer(NULL)		{}
+	CSG_UI_Parameter(bool              Value)	: Boolean(Value), Number( 0.0 ), Pointer(NULL)		{}
+	CSG_UI_Parameter(int               Value)	: Boolean(false), Number(Value), Pointer(NULL)		{}
+	CSG_UI_Parameter(double            Value)	: Boolean(false), Number(Value), Pointer(NULL)		{}
+	CSG_UI_Parameter(const CSG_String &Value)	: Boolean(false), Number( 0.0 ), Pointer(NULL), String(Value)	{}
+	CSG_UI_Parameter(void             *Value)	: Boolean(false), Number( 0.0 ), Pointer(Value)	{}
 	CSG_UI_Parameter(const CSG_UI_Parameter &Copy);
 
-	bool		True;
+	bool		Boolean;
 
 	double		Number;
 
