@@ -498,6 +498,47 @@ bool CSG_Grid::is_Compatible(int NX, int NY, double Cellsize, double xMin, doubl
 }
 
 
+///////////////////////////////////////////////////////////
+//														 //
+//					value access by row					 //
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+CSG_Vector CSG_Grid::Get_Row(int y)	const
+{
+	CSG_Vector	Values;
+
+	if( y >= 0 && y < Get_NY() )
+	{
+		Values.Create(Get_NX());
+
+		for(int x=0; x<Get_NX(); x++)
+		{
+			Values[x]	= asDouble(x, y);
+		}
+	}
+
+	return( Values );
+}
+
+//---------------------------------------------------------
+bool CSG_Grid::Set_Row(int y, const CSG_Vector &Values)
+{
+	if( y >= 0 && y < Get_NY() && Values.Get_N() == Get_NX() )
+	{
+		for(int x=0; x<Get_NX(); x++)
+		{
+			Set_Value(x, y, Values[x]);
+		}
+
+		return( true );
+	}
+	
+	return( false );
+}
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 //		Value access by Position (-> Interpolation)		 //
@@ -937,6 +978,7 @@ bool CSG_Grid::On_Update(void)
 		SG_FREE_SAFE(m_Index);
 
 		m_Statistics.Invalidate();
+		m_Histogram.Destroy();
 
 		double	Offset = Get_Offset(), Scaling = is_Scaled() ? Get_Scaling() : 0.0;
 
@@ -1023,20 +1065,34 @@ sLong CSG_Grid::Get_NoData_Count(void)
 }
 
 //---------------------------------------------------------
-double CSG_Grid::Get_Quantile(double Quantile)
+double CSG_Grid::Get_Quantile(double Quantile, bool bFromHistogram)
 {
-	Quantile	= Quantile <= 0.0 ? 0.0 : Quantile >= 100.0 ? 1.0 : Quantile / 100.0;
+	if( Quantile <= 0. ) { return( Get_Min() ); }
+	if( Quantile >= 1. ) { return( Get_Max() ); }
 
-	sLong	n	= (sLong)(Quantile * (Get_Data_Count() - 1));
-
-	if( Get_Sorted(n, n, false) )
+	if( bFromHistogram )
 	{
-		return( asDouble(n) );
+		return( Get_Histogram().Get_Quantile(Quantile) );
+	}
+	else
+	{
+		sLong	n	= (sLong)(Quantile * (Get_Data_Count() - 1));
+
+		if( Get_Sorted(n, n, false) )
+		{
+			return( asDouble(n) );
+		}
 	}
 
 	return( Get_NoData_Value() );
 }
 
+//---------------------------------------------------------
+double CSG_Grid::Get_Percentile(double Percentile, bool bFromHistogram)
+{
+	return( Get_Quantile(0.01 * Percentile, bFromHistogram) );
+}
+
 
 ///////////////////////////////////////////////////////////
 //														 //
@@ -1117,6 +1173,95 @@ bool CSG_Grid::Get_Statistics(const CSG_Rect &rWorld, CSG_Simple_Statistics &Sta
 	return( Statistics.Get_Count() > 0 );
 }
 
+//---------------------------------------------------------
+#define SG_GRID_HISTOGRAM_CLASSES_DEFAULT	255
+
+//---------------------------------------------------------
+/**
+* Returns the histogram for the whole data set. It is
+* automatically updated if necessary.
+*/
+const CSG_Histogram & CSG_Grid::Get_Histogram(size_t nClasses)
+{
+	Update();
+
+	if( nClasses > 1 && nClasses != m_Histogram.Get_Class_Count() )
+	{
+		m_Histogram.Destroy();
+	}
+
+	if( m_Histogram.Get_Statistics().Get_Count() < 1 )
+	{
+		m_Histogram.Create(nClasses > 1 ? nClasses : SG_GRID_HISTOGRAM_CLASSES_DEFAULT, Get_Min(), Get_Max(), this, (size_t)Get_Max_Samples());
+	}
+
+	return( m_Histogram );
+}
+
+//---------------------------------------------------------
+bool CSG_Grid::Get_Histogram(const CSG_Rect &rWorld, CSG_Histogram &Histogram, size_t nClasses)	const
+{
+	CSG_Simple_Statistics	Statistics;
+
+	if( !Get_Statistics(rWorld, Statistics) )
+	{
+		return( false );
+	}
+
+	int	xMin	= Get_System().Get_xWorld_to_Grid(rWorld.Get_XMin()); if( xMin <  0        ) xMin = 0;
+	int	yMin	= Get_System().Get_yWorld_to_Grid(rWorld.Get_YMin()); if( yMin <  0        ) yMin = 0;
+	int	xMax	= Get_System().Get_xWorld_to_Grid(rWorld.Get_XMax()); if( xMax >= Get_NX() ) xMax = Get_NX() - 1;
+	int	yMax	= Get_System().Get_yWorld_to_Grid(rWorld.Get_YMax()); if( yMax >= Get_NY() ) yMax = Get_NY() - 1;
+
+	if( xMin > xMax || yMin > yMax )
+	{
+		return( false );	// no overlap
+	}
+
+	Histogram.Create(nClasses > 1 ? nClasses : SG_GRID_HISTOGRAM_CLASSES_DEFAULT, Statistics.Get_Minimum(), Statistics.Get_Maximum());
+
+	int		nx		= 1 + (xMax - xMin);
+	int		ny		= 1 + (yMax - yMin);
+	sLong	nCells	= nx * ny;
+
+	double	Offset = Get_Offset(), Scaling = is_Scaled() ? Get_Scaling() : 0.0;
+
+	if( Get_Max_Samples() > 0 && Get_Max_Samples() < nCells )
+	{
+		double	d = (double)nCells / (double)Get_Max_Samples();
+
+		for(double i=0; i<(double)nCells; i+=d)
+		{
+			int	y	= yMin + (int)i / nx;
+			int	x	= xMin + (int)i % nx;
+
+			double	Value	= asDouble(x, y, false);
+
+			if( !is_NoData_Value(Value) )
+			{
+				Histogram	+= Scaling ? Offset + Scaling * Value : Value;
+			}
+		}
+	}
+	else
+	{
+		for(int y=yMin; y<=yMax; y++)
+		{
+			for(int x=xMin; x<=xMax; x++)
+			{
+				double	Value	= asDouble(x, y, false);
+
+				if( !is_NoData_Value(Value) )
+				{
+					Histogram	+= Scaling ? Offset + Scaling * Value : Value;
+				}
+			}
+		}
+	}
+
+	return( Histogram.Update() );
+}
+
 
 ///////////////////////////////////////////////////////////
 //														 //
@@ -1125,8 +1270,6 @@ bool CSG_Grid::Get_Statistics(const CSG_Rect &rWorld, CSG_Simple_Statistics &Sta
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-#define SORT_SWAP(a,b)	{itemp=(a);(a)=(b);(b)=itemp;}
-
 bool CSG_Grid::_Set_Index(void)
 {
 	//-----------------------------------------------------
@@ -1219,6 +1362,8 @@ bool CSG_Grid::_Set_Index(void)
 		//-------------------------------------------------
 		else
 		{
+			#define SORT_SWAP(a,b)	{itemp=(a);(a)=(b);(b)=itemp;}
+
 			k		= (l + ir) >> 1;
 
 			SORT_SWAP(m_Index[k], m_Index[l + 1]);
@@ -1250,6 +1395,8 @@ bool CSG_Grid::_Set_Index(void)
 				SORT_SWAP(m_Index[i], m_Index[j]);
 			}
 
+			#undef SORT_SWAP
+
 			m_Index[l]	= m_Index[j];
 			m_Index[j]	= indxt;
 			jstack		+= 2;
@@ -1282,7 +1429,6 @@ bool CSG_Grid::_Set_Index(void)
 
 	return( true );
 }
-#undef SORT_SWAP
 
 
 ///////////////////////////////////////////////////////////
