@@ -570,6 +570,7 @@ public:
 	bool						Create				(const CSG_Vector &Values, bool bHoldValues = false);
 
 	void						Invalidate			(void);
+	bool						Evaluate			(void);
 
 	int							is_Evaluated		(void)	const	{	return( m_bEvaluated );	}
 
@@ -837,20 +838,20 @@ public:
 
 	bool			Destroy				(void);
 
-	CSG_Histogram						(int nClasses, double Minimum, double Maximum);
-	bool			Create				(int nClasses, double Minimum, double Maximum);
+	CSG_Histogram						(size_t nClasses, double Minimum, double Maximum);
+	bool			Create				(size_t nClasses, double Minimum, double Maximum);
 
-	CSG_Histogram						(int nClasses, double Minimum, double Maximum, const CSG_Vector &Values          , unsigned int maxSamples = 0);
-	bool			Create				(int nClasses, double Minimum, double Maximum, const CSG_Vector &Values          , unsigned int maxSamples = 0);
+	CSG_Histogram						(size_t nClasses, double Minimum, double Maximum, const CSG_Vector &Values          , size_t maxSamples = 0);
+	bool			Create				(size_t nClasses, double Minimum, double Maximum, const CSG_Vector &Values          , size_t maxSamples = 0);
 
-	CSG_Histogram						(int nClasses, double Minimum, double Maximum, class CSG_Table *pTable, int Field, unsigned int maxSamples = 0);
-	bool			Create				(int nClasses, double Minimum, double Maximum, class CSG_Table *pTable, int Field, unsigned int maxSamples = 0);
+	CSG_Histogram						(size_t nClasses, double Minimum, double Maximum, class CSG_Table *pTable, int Field, size_t maxSamples = 0);
+	bool			Create				(size_t nClasses, double Minimum, double Maximum, class CSG_Table *pTable, int Field, size_t maxSamples = 0);
 
-	CSG_Histogram						(int nClasses, double Minimum, double Maximum, class CSG_Grid  *pGrid            , unsigned int maxSamples = 0);
-	bool			Create				(int nClasses, double Minimum, double Maximum, class CSG_Grid  *pGrid            , unsigned int maxSamples = 0);
+	CSG_Histogram						(size_t nClasses, double Minimum, double Maximum, class CSG_Grid  *pGrid            , size_t maxSamples = 0);
+	bool			Create				(size_t nClasses, double Minimum, double Maximum, class CSG_Grid  *pGrid            , size_t maxSamples = 0);
 
-	CSG_Histogram						(int nClasses, double Minimum, double Maximum, class CSG_Grids *pGrids           , unsigned int maxSamples = 0);
-	bool			Create				(int nClasses, double Minimum, double Maximum, class CSG_Grids *pGrids           , unsigned int maxSamples = 0);
+	CSG_Histogram						(size_t nClasses, double Minimum, double Maximum, class CSG_Grids *pGrids           , size_t maxSamples = 0);
+	bool			Create				(size_t nClasses, double Minimum, double Maximum, class CSG_Grids *pGrids           , size_t maxSamples = 0);
 
 	//-----------------------------------------------------
 	void			Add_Value			(double Value);
@@ -859,16 +860,16 @@ public:
 
 	bool			Update				(void);
 
-	unsigned int	Get_Class_Count		(void)		const	{	return( m_nClasses );	}
+	size_t			Get_Class_Count		(void)		const	{	return( m_nClasses );	}
 
-	unsigned int	Get_Element_Count	(void)		const	{	return( m_nClasses > 0 ? m_Cumulative[m_nClasses - 1] : 0 );	}
-	unsigned int	Get_Element_Maximum	(void)		const	{	return( m_nMaximum );	}
+	size_t			Get_Element_Count	(void)		const	{	return( m_nClasses > 0 ? m_Cumulative[m_nClasses - 1] : 0 );	}
+	size_t			Get_Element_Maximum	(void)		const	{	return( m_nMaximum );	}
 
-	unsigned int	Get_Elements		(int    i)	const	{	return( Get_Elements((size_t)i) );	}
-	unsigned int	Get_Elements		(size_t i)	const	{	return( i < m_nClasses ? m_Elements[i] : 0 );	}
+	size_t			Get_Elements		(int    i)	const	{	return( Get_Elements((size_t)i) );	}
+	size_t			Get_Elements		(size_t i)	const	{	return( i < m_nClasses ? m_Elements[i] : 0 );	}
 
-	unsigned int	Get_Cumulative		(int    i)	const	{	return( Get_Cumulative((size_t)i) );	}
-	unsigned int	Get_Cumulative		(size_t i)	const	{	return( i < m_nClasses ? m_Cumulative[i] : 0 );	}
+	size_t			Get_Cumulative		(int    i)	const	{	return( Get_Cumulative((size_t)i) );	}
+	size_t			Get_Cumulative		(size_t i)	const	{	return( i < m_nClasses ? m_Cumulative[i] : 0 );	}
 
 	double			Get_Value			(double i)	const	{	return( m_nClasses > 0 ? m_Minimum + i * (m_Maximum - m_Minimum) / m_nClasses : m_Minimum );	}
 
@@ -881,9 +882,10 @@ public:
 	//-----------------------------------------------------
 	void			operator +=			(double Value)		{	Add_Value(Value);	}
 
-	unsigned int	operator []			(int    i)	const	{	return( Get_Elements(i) );	}
-	unsigned int	operator []			(size_t i)	const	{	return( Get_Elements(i) );	}
+	size_t			operator []			(int    i)	const	{	return( Get_Elements(i) );	}
+	size_t			operator []			(size_t i)	const	{	return( Get_Elements(i) );	}
 
+	double			Get_Quantile		(double   Quantile)	const;
 	double			Get_Percentile		(double Percentile)	const;
 
 	const CSG_Simple_Statistics &	Get_Statistics	(void)	const	{	return( m_Statistics );	}
@@ -891,7 +893,7 @@ public:
 
 private:
 
-	unsigned int			m_nClasses, m_nMaximum, *m_Elements, *m_Cumulative;
+	size_t					m_nClasses, m_nMaximum, *m_Elements, *m_Cumulative;
 
 	double					m_Minimum, m_Maximum;
 
@@ -900,7 +902,7 @@ private:
 
 	void					_On_Construction	(void);
 
-	bool					_Create				(int nClasses, double Minimum, double Maximum);
+	bool					_Create				(size_t nClasses, double Minimum, double Maximum);
 
 	bool					_Update				(sLong nElements);
 
@@ -1769,7 +1771,8 @@ enum ESG_Trend_String
 	SG_TREND_STRING_Formula	= 0,
 	SG_TREND_STRING_Function,
 	SG_TREND_STRING_Formula_Parameters,
-	SG_TREND_STRING_Complete
+	SG_TREND_STRING_Complete,
+	SG_TREND_STRING_Compact
 };
 
 //---------------------------------------------------------
@@ -1789,13 +1792,15 @@ public:
 	bool						Add_Data			(double  x, double  y);
 	void						Set_Data			(double *x, double *y, int n, bool bAdd = false);
 	void						Set_Data			(const CSG_Points &Data     , bool bAdd = false);
-	int							Get_Data_Count		(void)	const	{	return( m_Data.Get_NCols() );	}
+	int							Get_Data_Count		(void)	const	{	return( (int)m_Data[0].Get_Count() );	}
 	double						Get_Data_X			(int i)	const	{	return( m_Data[0][i] );	}
+	double						Get_Data_XMin		(void)			{	return( m_Data[0].Get_Minimum() );	}
+	double						Get_Data_XMax		(void)			{	return( m_Data[0].Get_Maximum() );	}
+	CSG_Simple_Statistics &		Get_Data_XStats		(void)			{	return( m_Data[0] );	}
 	double						Get_Data_Y			(int i)	const	{	return( m_Data[1][i] );	}
-	double						Get_Data_XMin		(void)	const	{	return( m_xMin );	}
-	double						Get_Data_XMax		(void)	const	{	return( m_xMax );	}
-	double						Get_Data_YMin		(void)	const	{	return( m_yMin );	}
-	double						Get_Data_YMax		(void)	const	{	return( m_yMax );	}
+	double						Get_Data_YMin		(void)			{	return( m_Data[1].Get_Minimum() );	}
+	double						Get_Data_YMax		(void)			{	return( m_Data[1].Get_Maximum() );	}
+	CSG_Simple_Statistics &		Get_Data_YStats		(void)			{	return( m_Data[1] );	}
 
 	bool						Set_Max_Iterations	(int Iterations);
 	int							Get_Max_Iterations	(void)	const	{	return( m_Iter_Max);	}
@@ -1845,11 +1850,11 @@ private:
 
 	int							m_Iter_Max;
 
-	double						m_ChiSqr, m_ChiSqr_o, m_Lambda, m_Lambda_Max, m_xMin, m_xMax, m_yMin, m_yMax;
+	double						m_ChiSqr, m_ChiSqr_o, m_Lambda, m_Lambda_Max;
 
 	CParams						m_Params;
 
-	CSG_Matrix					m_Data;
+	CSG_Simple_Statistics		m_Data[2];
 
 	CSG_Formula					m_Formula;
 
