@@ -335,8 +335,8 @@ CSG_Parameter_Value::CSG_Parameter_Value(CSG_Parameters *pOwner, CSG_Parameter *
 //---------------------------------------------------------
 bool CSG_Parameter_Value::Set_Valid_Range(double Minimum, double Maximum)
 {
-	m_Minimum	= Minimum < Maximum ? Minimum : Maximum;
-	m_Maximum	= Minimum < Maximum ? Maximum : Minimum;
+	m_Minimum	= !m_bMaximum || Minimum < Maximum ? Minimum : Maximum;
+	m_Maximum	= !m_bMinimum || Minimum < Maximum ? Maximum : Minimum;
 
 	switch( Get_Type() )
 	{
@@ -739,7 +739,14 @@ bool CSG_Parameter_Range::Set_Range(double Min, double Max)
 //---------------------------------------------------------
 bool CSG_Parameter_Range::Set_Min(double Value)
 {
-	return( m_pMin->Set_Value(Value) );
+	if( m_pMin->Set_Value(Value) )
+	{
+		has_Changed();
+
+		return( true );
+	}
+
+	return( false );
 }
 
 double CSG_Parameter_Range::Get_Min(void)	const
@@ -750,7 +757,14 @@ double CSG_Parameter_Range::Get_Min(void)	const
 //---------------------------------------------------------
 bool CSG_Parameter_Range::Set_Max(double Value)
 {
-	return( m_pMax->Set_Value(Value) );
+	if( m_pMax->Set_Value(Value) )
+	{
+		has_Changed();
+
+		return( true );
+	}
+
+	return( false );
 }
 
 double CSG_Parameter_Range::Get_Max(void)	const
@@ -1749,6 +1763,8 @@ int CSG_Parameter_Grid_System::_Set_Value(void *Value)
 					pList->Del_Item(j);
 				}
 			}
+
+			pParameter->has_Changed();
 		}
 	}
 
@@ -1816,6 +1832,7 @@ CSG_Parameter_Table_Field::CSG_Parameter_Table_Field(CSG_Parameters *pOwner, CSG
 	: CSG_Parameter_Int(pOwner, pParent, ID, Name, Description, Constraint)
 {
 	m_Default	= -1;
+	m_Value		= -1;
 }
 
 //---------------------------------------------------------
@@ -1881,13 +1898,20 @@ int CSG_Parameter_Table_Field::_Set_Value(const CSG_String &Value)
 
 	if( pTable != NULL )
 	{
-		for(int i=0; i<pTable->Get_Field_Count(); i++)
+		int	Index;
+
+		for(Index=0; Index<pTable->Get_Field_Count(); Index++)
 		{
-			if( !Value.CmpNoCase(pTable->Get_Field_Name(i)) )
+			if( !Value.CmpNoCase(pTable->Get_Field_Name(Index)) )
 			{
-				return( _Set_Value(i) );
+				return( _Set_Value(Index) );
 			}
 		}
+
+		if( Value.asInt(Index) )
+		{
+			return( _Set_Value(Index) );
+		}
 	}
 
 	return( _Set_Value(-1) );
@@ -2161,33 +2185,75 @@ bool CSG_Parameter_Data_Object::_Serialize(CSG_MetaData &Entry, bool bSave)
 		if(	m_pDataObject == DATAOBJECT_CREATE )
 		{
 			Entry.Set_Content("CREATE");
+
+			return( true );
 		}
-		else if( m_pDataObject == DATAOBJECT_NOTSET )//|| !SG_File_Exists(m_pDataObject->Get_File_Name(false)) )
+
+		if( m_pDataObject == DATAOBJECT_NOTSET )//|| !SG_File_Exists(m_pDataObject->Get_File_Name(false)) )
 		{
 			Entry.Set_Content("NOT SET");
+
+			return( true );
 		}
-		else
+
+		if( !m_pDataObject->Get_Owner() )
 		{
 			Entry.Set_Content(m_pDataObject->Get_File_Name(false));
+
+			return( true );
+		}
+
+		if( m_pDataObject->Get_Owner()->Get_ObjectType() == SG_DATAOBJECT_TYPE_Grids )
+		{
+			CSG_Grids	*pGrids	= m_pDataObject->Get_Owner()->asGrids();
+
+			for(int i=0; i<pGrids->Get_NZ(); i++)
+			{
+				if( pGrids->Get_Grid_Ptr(i) == m_pDataObject )
+				{
+					Entry.Set_Content(m_pDataObject->Get_Owner()->Get_File_Name(false));
+
+					Entry.Add_Property("index", i);
+
+					return( true );
+				}
+			}
 		}
 	}
 	else
 	{
+		CSG_Data_Object	*pDataObject = NULL; int Index = -1;
+
 		if( Entry.Cmp_Content("CREATE") )
 		{
 			_Set_Value(DATAOBJECT_CREATE);
+
+			return( true );
 		}
-		else if( Entry.Cmp_Content("NOT SET") )
+
+		if( Entry.Cmp_Content("NOT SET") || !Get_Manager() || !(pDataObject = Get_Manager()->Find(Entry.Get_Content(), false)) )
 		{
 			_Set_Value(DATAOBJECT_NOTSET);
+
+			return( true );
 		}
-		else
+
+		if( !Entry.Get_Property("index", Index) )
 		{
-			_Set_Value(Get_Manager() ? Get_Manager()->Find(Entry.Get_Content(), false) : NULL);
+			_Set_Value(pDataObject);
+
+			return( true );
+		}
+
+		if( pDataObject->Get_ObjectType() == SG_DATAOBJECT_TYPE_Grids )
+		{
+			_Set_Value(pDataObject->asGrids()->Get_Grid_Ptr(Index));
+
+			return( true );
 		}
 	}
 
-	return( true );
+	return( false );
 }
 
 
@@ -2348,7 +2414,7 @@ int CSG_Parameter_Grid::_Set_Value(void *Value)
 				}
 			}
 
-			Get_System()->Assign(System);
+			Get_Parent()->Set_Value((void *)&System);
 		}
 	}
 
@@ -2777,7 +2843,7 @@ bool CSG_Parameter_Grid_List::Add_Item(CSG_Data_Object *pObject)
 				}
 			}
 
-			Get_System()->Assign(System);
+			Get_Parent()->Set_Value((void *)&System);
 		}
 	}
 
@@ -2899,7 +2965,7 @@ bool CSG_Parameter_Grids_List::Add_Item(CSG_Data_Object *pObject)
 				}
 			}
 
-			Get_System()->Assign(((CSG_Grids *)pObject)->Get_System());
+			Get_Parent()->Set_Value((void *)&System);
 		}
 	}
 
