@@ -149,14 +149,7 @@ CSG_Table::CSG_Table(const CSG_Table &Table)
 
 bool CSG_Table::Create(const CSG_Table &Table)
 {
-	if( Assign((CSG_Data_Object *)&Table) )
-	{
-		Set_Name(Table.Get_Name());
-
-		return( true );
-	}
-
-	return( false );
+	return( Assign((CSG_Data_Object *)&Table) );
 }
 
 //---------------------------------------------------------
@@ -191,7 +184,7 @@ bool CSG_Table::Create(const CSG_String &File_Name, TSG_Table_File_Type Format)
 		s	= s.AfterFirst(':');	CSG_String	DBName(s.BeforeFirst(':'));
 		s	= s.AfterFirst(':');	CSG_String	Table (s.BeforeFirst(':'));
 
-		CSG_Tool	*pTool	= SG_Get_Tool_Library_Manager().Get_Tool("db_pgsql", 0);	// CGet_Connections
+		CSG_Tool	*pTool	= SG_Get_Tool_Library_Manager().Create_Tool("db_pgsql", 0);	// CGet_Connections
 
 		if(	pTool != NULL )
 		{
@@ -201,8 +194,8 @@ bool CSG_Table::Create(const CSG_String &File_Name, TSG_Table_File_Type Format)
 			CSG_Table	Connections;
 			CSG_String	Connection	= DBName + " [" + Host + ":" + Port + "]";
 
+			pTool->Set_Manager(NULL);
 			pTool->On_Before_Execution();
-			pTool->Settings_Push();
 
 			if( SG_TOOL_PARAMETER_SET("CONNECTIONS", &Connections) && pTool->Execute() )	// CGet_Connections
 			{
@@ -215,20 +208,20 @@ bool CSG_Table::Create(const CSG_String &File_Name, TSG_Table_File_Type Format)
 				}
 			}
 
-			pTool->Settings_Pop();
+			SG_Get_Tool_Library_Manager().Delete_Tool(pTool);
 
 			//---------------------------------------------
-			if( bResult && (bResult = (pTool = SG_Get_Tool_Library_Manager().Get_Tool("db_pgsql", 12)) != NULL) == true )	// CPGIS_Table_Load
+			if( bResult && (bResult = (pTool = SG_Get_Tool_Library_Manager().Create_Tool("db_pgsql", 12)) != NULL) == true )	// CPGIS_Table_Load
 			{
+				pTool->Set_Manager(NULL);
 				pTool->On_Before_Execution();
-				pTool->Settings_Push();
 
 				bResult	=  SG_TOOL_PARAMETER_SET("CONNECTION", Connection)
 						&& SG_TOOL_PARAMETER_SET("TABLES"    , Table)
 						&& SG_TOOL_PARAMETER_SET("TABLE"     , this)
 						&& pTool->Execute();
 
-				pTool->Settings_Pop();
+				SG_Get_Tool_Library_Manager().Delete_Tool(pTool);
 			}
 
 			SG_UI_ProgressAndMsg_Lock(false);
@@ -278,26 +271,28 @@ CSG_Table::CSG_Table(const CSG_Table *pTemplate)
 
 bool CSG_Table::Create(const CSG_Table *pTemplate)
 {
-	Destroy();
-
-	if( pTemplate && pTemplate->Get_Field_Count() > 0 )
+	if( !pTemplate || pTemplate->Get_Field_Count() < 1 )
 	{
-		for(int i=0; i<pTemplate->Get_Field_Count(); i++)
-		{
-			Add_Field(pTemplate->Get_Field_Name(i), pTemplate->Get_Field_Type(i));
-		}
-
-		return( true );
+		return( false );
 	}
 
-	return( false );
+	Destroy();
+
+	Set_Name              (pTemplate->Get_Name       ());
+	Set_Description       (pTemplate->Get_Description());
+	Set_NoData_Value_Range(pTemplate->Get_NoData_Value(), pTemplate->Get_NoData_hiValue());
+
+	for(int i=0; i<pTemplate->Get_Field_Count(); i++)
+	{
+		Add_Field(pTemplate->Get_Field_Name(i), pTemplate->Get_Field_Type(i));
+	}
+
+	return( true );
 }
 
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -322,8 +317,6 @@ void CSG_Table::_On_Construction(void)
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -389,20 +382,16 @@ bool CSG_Table::Assign(CSG_Data_Object *pObject)
 		return( false );
 	}
 
-	Destroy();
-
 	CSG_Table	*pTable	= (CSG_Table *)pObject;
 
-	Set_NoData_Value_Range(pTable->Get_NoData_Value(), pTable->Get_NoData_hiValue());
-
-	for(int iField=0; iField<pTable->m_nFields; iField++)
+	if( !Create(pTable) )
 	{
-		Add_Field(pTable->m_Field_Name[iField]->c_str(), pTable->m_Field_Type[iField]);
+		return( false );
 	}
 
-	for(int iRecord=0; iRecord<pTable->m_nRecords; iRecord++)
+	for(int i=0; i<pTable->Get_Count(); i++)
 	{
-		Add_Record(pTable->m_Records[iRecord]);
+		Add_Record(pTable->Get_Record(i));
 	}
 
 	Get_History()	= pTable->Get_History();
@@ -436,7 +425,7 @@ bool CSG_Table::Assign_Values(CSG_Table *pTable)
 //---------------------------------------------------------
 bool CSG_Table::is_Compatible(CSG_Table *pTable, bool bExactMatch) const
 {
-	if( Get_Field_Count() == pTable->Get_Field_Count() )
+	if( pTable && Get_Field_Count() == pTable->Get_Field_Count() )
 	{
 		for(int i=0; i<Get_Field_Count(); i++)
 		{
@@ -505,7 +494,7 @@ bool CSG_Table::Add_Field(const CSG_String &Name, TSG_Data_Type Type, int add_Fi
 	}
 
 	//-----------------------------------------------------
-	m_Field_Name [add_Field]	= new CSG_String(!Name.is_Empty() ? Name : CSG_String::Format(SG_T("%s_%d"), SG_T("FIELD"), m_nFields));
+	m_Field_Name [add_Field]	= new CSG_String(!Name.is_Empty() ? Name : CSG_String::Format("FIELD_%d", m_nFields));
 	m_Field_Type [add_Field]	= Type;
 	m_Field_Stats[add_Field]	= new CSG_Simple_Statistics();
 
@@ -1212,17 +1201,21 @@ bool CSG_Table::_Stats_Update(int iField) const
 {
 	if( iField >= 0 && iField < m_nFields && m_nRecords > 0 )
 	{
-		if( !m_Field_Stats[iField]->is_Evaluated() )
-		{
-			CSG_Table_Record	**ppRecord	= m_Records;
+		CSG_Simple_Statistics	*pStatistics	= m_Field_Stats[iField];
 
-			for(int iRecord=0; iRecord<m_nRecords; iRecord++, ppRecord++)
+		if( !pStatistics->is_Evaluated() )
+		{
+			for(int iRecord=0; iRecord<m_nRecords; iRecord++)
 			{
-				if( !(*ppRecord)->is_NoData(iField) )
+				CSG_Table_Record	*pRecord	= m_Records[iRecord];
+
+				if( !pRecord->is_NoData(iField) )
 				{
-					m_Field_Stats[iField]->Add_Value((*ppRecord)->asDouble(iField));
+					pStatistics->Add_Value(pRecord->asDouble(iField));
 				}
 			}
+
+			pStatistics->Evaluate();	// evaluate! prevent values to be added more than once!
 		}
 
 		return( true );
@@ -1232,6 +1225,21 @@ bool CSG_Table::_Stats_Update(int iField) const
 }
 
 
+///////////////////////////////////////////////////////////
+//														 //
+//														 //
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+bool CSG_Table::On_NoData_Changed(void)
+{
+	_Stats_Invalidate();
+
+	return( CSG_Data_Object::On_NoData_Changed() );
+}
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 //						Index							 //
