@@ -284,7 +284,7 @@ bool CSG_Tool::Execute(void)
 		Parameters.Msg_String(false);
 
 ///////////////////////////////////////////////////////////
-#if !defined(_DEBUG) && defined(_SAGA_VC) && defined(WXWIN_28)
+#if !defined(_DEBUG) && !defined(_OPENMP) && defined(_SAGA_MSW)
 #define _TOOL_EXCEPTION
 		__try
 		{
@@ -1100,6 +1100,32 @@ bool CSG_Tool::Set_Parameter(const CSG_String &Identifier, const wchar_t *Value,
 }
 
 
+///////////////////////////////////////////////////////////
+//														 //
+//														 //
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+bool CSG_Tool::Set_Grid_System(const CSG_Grid_System &System)
+{
+//	for(int i=0; i<m_npParameters; i++)
+//	{
+//		m_pParameters[i]->Set_Grid_System(System);
+//	}
+
+	return( Parameters.Set_Grid_System(System) );
+}
+
+//---------------------------------------------------------
+bool CSG_Tool::Reset_Grid_System(void)
+{
+	CSG_Grid_System	System;
+
+	return( Set_Grid_System(System) );
+}
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 //														 //
