@@ -153,7 +153,7 @@ static	wxString	g_Password	= "postgres";
 //---------------------------------------------------------
 #define RUN_TOOL(TOOL, bManager, CONDITION)	bool bResult = false;\
 {\
-	CSG_Tool	*pTool	= SG_Get_Tool_Library_Manager().Get_Tool("db_pgsql", TOOL);\
+	CSG_Tool	*pTool	= SG_Get_Tool_Library_Manager().Create_Tool("db_pgsql", TOOL);\
 	\
 	if(	pTool )\
 	{\
@@ -163,6 +163,7 @@ static	wxString	g_Password	= "postgres";
 		bResult	= (CONDITION) && pTool->Execute();\
 		pTool->Settings_Pop();\
 		SG_UI_Msg_Lock(false);\
+		SG_Get_Tool_Library_Manager().Delete_Tool(pTool);\
 	}\
 }
 
@@ -190,11 +191,11 @@ bool	PGSQL_Connect			(const CSG_String &Host, const CSG_String &Port, const CSG_
 	}
 
 	RUN_TOOL(DB_PGSQL_Get_Connection, false,	// CGet_Connection
-			SET_PARAMETER("PG_HOST",   Host    )
-		&&	SET_PARAMETER("PG_PORT",   Port    )
-		&&	SET_PARAMETER("PG_NAME",   DBName  )
-		&&	SET_PARAMETER("PG_USER", &g_Username)
-		&&	SET_PARAMETER("PG_PWD" , &g_Password)
+			SET_PARAMETER("PG_HOST", Host  )
+		&&	SET_PARAMETER("PG_PORT", Port  )
+		&&	SET_PARAMETER("PG_NAME", DBName)
+		&&	SET_PARAMETER("PG_USER", CSG_String(&g_Username))
+		&&	SET_PARAMETER("PG_PWD" , CSG_String(&g_Password))
 	);
 
 	return( bResult );
@@ -265,86 +266,77 @@ bool	PGSQL_has_Connections	(double vPostGIS)
 //---------------------------------------------------------
 bool	PGSQL_Save_Table	(CSG_Table *pTable)
 {
-	CSG_Tool	*pTool	= SG_Get_Tool_Library_Manager().Get_Tool("db_pgsql", DB_PGSQL_Table_Save);
+	CSG_Tool	*pTool	= SG_Get_Tool_Library_Manager().Create_Tool("db_pgsql", DB_PGSQL_Table_Save);
 
 	SG_UI_Msg_Lock(true);
 
-	if(	pTool && pTool->On_Before_Execution() && pTool->Set_Parameter("TABLE", pTable)
-	&&  DLG_Parameters(pTool->Get_Parameters()) && pTool->Execute() )
-	{
-		SG_UI_Msg_Lock(false);
-
-		return( true );
-	}
+	bool	bResult	= pTool && pTool->On_Before_Execution() && pTool->Set_Parameter("TABLE", pTable)
+		&&  DLG_Parameters(pTool->Get_Parameters()) && pTool->Execute();
 
 	SG_UI_Msg_Lock(false);
 
-	return( false );
+	SG_Get_Tool_Library_Manager().Delete_Tool(pTool);
+
+	return( bResult );
 }
 
 //---------------------------------------------------------
 bool	PGSQL_Save_Shapes	(CSG_Shapes *pShapes)
 {
-	CSG_Tool	*pTool	= SG_Get_Tool_Library_Manager().Get_Tool("db_pgsql", DB_PGSQL_Shapes_Save);
+	CSG_Tool	*pTool	= SG_Get_Tool_Library_Manager().Create_Tool("db_pgsql", DB_PGSQL_Shapes_Save);
 
 	SG_UI_Msg_Lock(true);
 
-	if(	pTool && pTool->On_Before_Execution() && pTool->Set_Parameter("SHAPES", pShapes)
-	&&  DLG_Parameters(pTool->Get_Parameters()) && pTool->Execute() )
-	{
-		SG_UI_Msg_Lock(false);
-
-		return( true );
-	}
+	bool	bResult	= pTool && pTool->On_Before_Execution() && pTool->Set_Parameter("SHAPES", pShapes)
+		&&  DLG_Parameters(pTool->Get_Parameters()) && pTool->Execute();
 
 	SG_UI_Msg_Lock(false);
 
-	return( false );
+	SG_Get_Tool_Library_Manager().Delete_Tool(pTool);
+
+	return( bResult );
 }
 
 //---------------------------------------------------------
 bool	PGSQL_Save_Grid		(CSG_Grid *pGrid)
 {
-	CSG_Tool	*pTool	= SG_Get_Tool_Library_Manager().Get_Tool("db_pgsql", DB_PGSQL_Raster_Save);
+	bool	bResult	= false;
+
+	CSG_Tool	*pTool	= SG_Get_Tool_Library_Manager().Create_Tool("db_pgsql", DB_PGSQL_Raster_Save);
 
 	SG_UI_Msg_Lock(true);
 
 	if(	pTool && pTool->On_Before_Execution() && pTool->Set_Parameter("NAME", pGrid->Get_Name()) )
 	{
-		pTool->Get_Parameters()->Get_Parameter("GRIDS")->asList()->Del_Items();
+		pTool->Get_Parameter("GRIDS")->asList()->Del_Items();
+		pTool->Get_Parameter("GRIDS")->asList()->Add_Item(pGrid);
+		pTool->Set_Parameter("CRS_EPSG", pGrid->Get_Projection().Get_EPSG());
 
-		if( pTool->Get_Parameters()->Get_Parameter("GRIDS")->asList()->Add_Item(pGrid)
-		&&  DLG_Parameters(pTool->Get_Parameters()) && pTool->Execute() )
-		{
-			SG_UI_Msg_Lock(false);
-
-			return( true );
-		}
+		bResult	= DLG_Parameters(pTool->Get_Parameters()) && pTool->Execute();
 	}
 
 	SG_UI_Msg_Lock(false);
 
+	SG_Get_Tool_Library_Manager().Delete_Tool(pTool);
+
 	return( false );
 }
 
 //---------------------------------------------------------
 bool	PGSQL_Save_Grids		(CSG_Grids *pGrids)
 {
-	CSG_Tool	*pTool	= SG_Get_Tool_Library_Manager().Get_Tool("db_pgsql", DB_PGSQL_Rasters_Save);
+	CSG_Tool	*pTool	= SG_Get_Tool_Library_Manager().Create_Tool("db_pgsql", DB_PGSQL_Rasters_Save);
 
 	SG_UI_Msg_Lock(true);
 
-	if(	pTool && pTool->On_Before_Execution() && pTool->Set_Parameter("GRIDS", pGrids)
-	&&  DLG_Parameters(pTool->Get_Parameters()) && pTool->Execute() )
-	{
-		SG_UI_Msg_Lock(false);
-
-		return( true );
-	}
+	bool	bResult	= pTool && pTool->On_Before_Execution() && pTool->Set_Parameter("GRIDS", pGrids)
+		&&  DLG_Parameters(pTool->Get_Parameters()) && pTool->Execute();
 
 	SG_UI_Msg_Lock(false);
 
-	return( false );
+	SG_Get_Tool_Library_Manager().Delete_Tool(pTool);
+
+	return( bResult );
 }
 
 
@@ -500,10 +492,10 @@ CData_Source_PgSQL::~CData_Source_PgSQL(void)
 				CONFIG_Write(CFG_PGSQL_DIR, wxString::Format(CFG_PGSQL_SRC, i++), Connection.c_str());
 			}
 
-			Item	= GetNextChild(Item, Cookie);
+			Item	= GetNextChild(srvItem, Cookie);
 		}
 
-		srvItem	= GetNextChild(srvItem, srvCookie);
+		srvItem	= GetNextChild(GetRootItem(), srvCookie);
 	}
 }
 
@@ -538,10 +530,10 @@ void CData_Source_PgSQL::Autoconnect(void)
 					Source_Open(pData, false);
 				}
 
-				Item	= GetNextChild(Item, Cookie);
+				Item	= GetNextChild(srvItem, Cookie);
 			}
 
-			srvItem	= GetNextChild(srvItem, srvCookie);
+			srvItem	= GetNextChild(GetRootItem(), srvCookie);
 		}
 	}
 }
@@ -751,7 +743,7 @@ wxTreeItemId CData_Source_PgSQL::Get_Server_Item(const wxString &Server, bool bC
 			return( Item );
 		}
 
-		Item	= GetNextChild(Item, Cookie);
+		Item	= GetNextChild(GetRootItem(), Cookie);
 	}
 
 	if( bCreate )
@@ -768,17 +760,17 @@ wxTreeItemId CData_Source_PgSQL::Get_Server_Item(const wxString &Server, bool bC
 //---------------------------------------------------------
 wxTreeItemId CData_Source_PgSQL::Find_Source(const wxString &Server)
 {
-	wxTreeItemId	Item	= Get_Server_Item(Server, false);
+	wxTreeItemId	Item, srvItem	= Get_Server_Item(Server, false);
 
-	if( Item.IsOk() )
+	if( srvItem.IsOk() )
 	{
-		wxTreeItemIdValue Cookie; Item = GetFirstChild(Item, Cookie);
+		wxTreeItemIdValue Cookie; Item = GetFirstChild(srvItem, Cookie);
 
 		wxString	Name	= Server.BeforeLast('['); Name.Trim(true);
 
 		while( Item.IsOk() && Name.Cmp(GetItemText(Item)) )
 		{
-			Item	= GetNextChild(Item, Cookie);
+			Item	= GetNextChild(srvItem, Cookie);
 		}
 	}
 
@@ -810,7 +802,7 @@ void CData_Source_PgSQL::Update_Sources(const wxTreeItemId &Root)
 	{
 		Update_Source(Item);
 
-		Item	= GetNextChild(Item, Cookie);
+		Item	= GetNextChild(Root, Cookie);
 	}
 
 	//-----------------------------------------------------
@@ -842,7 +834,7 @@ void CData_Source_PgSQL::Update_Sources(void)
 	{
 		Update_Sources(Item);
 
-		Item	= GetNextChild(Item, Cookie);
+		Item	= GetNextChild(GetRootItem(), Cookie);
 	}
 }
 
@@ -986,7 +978,7 @@ bool CData_Source_PgSQL::Source_Create(const wxTreeItemId &Item)
 	if( pData->Get_Type() == TYPE_ROOT
 	||  pData->Get_Type() == TYPE_SERVER )
 	{
-		CSG_Tool	*pTool	= SG_Get_Tool_Library_Manager().Get_Tool("db_pgsql", DB_PGSQL_DB_Create);
+		CSG_Tool	*pTool	= SG_Get_Tool_Library_Manager().Create_Tool("db_pgsql", DB_PGSQL_DB_Create);
 
 		SG_UI_Msg_Lock(true);
 
@@ -1005,6 +997,8 @@ bool CData_Source_PgSQL::Source_Create(const wxTreeItemId &Item)
 		}
 
 		SG_UI_Msg_Lock(false);
+
+		SG_Get_Tool_Library_Manager().Delete_Tool(pTool);
 	}
 
 	return( true );
@@ -1089,7 +1083,7 @@ void CData_Source_PgSQL::Source_Open(const wxTreeItemId &Item)
 	if( pData->Get_Type() == TYPE_ROOT
 	||  pData->Get_Type() == TYPE_SERVER )
 	{
-		CSG_Tool	*pTool	= SG_Get_Tool_Library_Manager().Get_Tool("db_pgsql", DB_PGSQL_Get_Connection);	// CGet_Connection
+		CSG_Tool	*pTool	= SG_Get_Tool_Library_Manager().Create_Tool("db_pgsql", DB_PGSQL_Get_Connection);	// CGet_Connection
 
 		SG_UI_Msg_Lock(true);
 
@@ -1108,6 +1102,8 @@ void CData_Source_PgSQL::Source_Open(const wxTreeItemId &Item)
 		}
 
 		SG_UI_Msg_Lock(false);
+
+		SG_Get_Tool_Library_Manager().Delete_Tool(pTool);
 	}
 	else if( pData->is_Connected() )
 	{
@@ -1214,7 +1210,7 @@ void CData_Source_PgSQL::Table_From_Query(const wxTreeItemId &Item)
 {
 	CData_Source_PgSQL_Data	*pData	= Item.IsOk() ? (CData_Source_PgSQL_Data *)GetItemData(Item) : NULL; if( pData == NULL )	return;
 
-	CSG_Tool	*pTool	= SG_Get_Tool_Library_Manager().Get_Tool("db_pgsql", DB_PGSQL_Table_Query);
+	CSG_Tool	*pTool	= SG_Get_Tool_Library_Manager().Create_Tool("db_pgsql", DB_PGSQL_Table_Query);
 
 	SG_UI_Msg_Lock(true);
 
@@ -1233,6 +1229,8 @@ void CData_Source_PgSQL::Table_From_Query(const wxTreeItemId &Item)
 	}
 
 	SG_UI_Msg_Lock(false);
+
+	SG_Get_Tool_Library_Manager().Delete_Tool(pTool);
 }
 
 //---------------------------------------------------------
