@@ -24,7 +24,8 @@
 // Geoscientific Analyses'. SAGA is free software; you   //
 // can redistribute it and/or modify it under the terms  //
 // of the GNU General Public License as published by the //
-// Free Software Foundation; version 2 of the License.   //
+// Free Software Foundation, either version 2 of the     //
+// License, or (at your option) any later version.       //
 //                                                       //
 // SAGA is distributed in the hope that it will be       //
 // useful, but WITHOUT ANY WARRANTY; without even the    //
@@ -33,10 +34,8 @@
 // License for more details.                             //
 //                                                       //
 // You should have received a copy of the GNU General    //
-// Public License along with this program; if not,       //
-// write to the Free Software Foundation, Inc.,          //
-// 51 Franklin Street, 5th Floor, Boston, MA 02110-1301, //
-// USA.                                                  //
+// Public License along with this program; if not, see   //
+// <http://www.gnu.org/licenses/>.                       //
 //                                                       //
 //-------------------------------------------------------//
 //                                                       //
@@ -90,6 +89,8 @@ const wxString CTRL_Get_Name(int ID_CTRL)
 	case ID_BTN_LOAD           :	return( _TL("Load") );
 	case ID_BTN_SAVE           :	return( _TL("Save") );
 
+	case ID_BTN_DESCRIPTION    :	return( _TL("Info") );
+
 	case ID_BTN_DEFAULTS       :	return( _TL("Defaults") );
 
 	case ID_BTN_ADD            :	return( _TL("Add") );
