@@ -136,6 +136,8 @@ enum ID_IMAGES
 	ID_IMG_TB_HISTOGRAM_AS_TABLE,
 	ID_IMG_TB_HISTOGRAM_CUMULATIVE,
 	ID_IMG_TB_INFO,
+	ID_IMG_TB_UPDATE,
+	ID_IMG_TB_CLIPBOARD,
 	ID_IMG_TB_LAYOUT_PAGE_SETUP,
 	ID_IMG_TB_LAYOUT_PRINT,
 	ID_IMG_TB_LAYOUT_PRINT_PREVIEW,
