@@ -174,7 +174,6 @@ public:
     virtual void				Tile						(wxOrientation orient = wxHORIZONTAL);
 
 	void						Close_Children				(void);
-	int							Get_Children_Count			(void);
 	void						On_Child_Activates			(int View_ID);
 
 	void						Set_Pane_Caption			(wxWindow *pWindow, const wxString &Caption);
@@ -208,6 +207,8 @@ private:
 	class wxAuiManager			*m_pLayout;
 
 
+	int							_Get_MDI_Children_Count		(void);
+
 	class wxMenuBar *			_Create_MenuBar				(void);
 
 	void						_Bar_Add					(wxWindow *pWindow, int Position, int Row);
