@@ -24,7 +24,8 @@
 // Geoscientific Analyses'. SAGA is free software; you   //
 // can redistribute it and/or modify it under the terms  //
 // of the GNU General Public License as published by the //
-// Free Software Foundation; version 2 of the License.   //
+// Free Software Foundation, either version 2 of the     //
+// License, or (at your option) any later version.       //
 //                                                       //
 // SAGA is distributed in the hope that it will be       //
 // useful, but WITHOUT ANY WARRANTY; without even the    //
@@ -33,10 +34,8 @@
 // License for more details.                             //
 //                                                       //
 // You should have received a copy of the GNU General    //
-// Public License along with this program; if not,       //
-// write to the Free Software Foundation, Inc.,          //
-// 51 Franklin Street, 5th Floor, Boston, MA 02110-1301, //
-// USA.                                                  //
+// Public License along with this program; if not, see   //
+// <http://www.gnu.org/licenses/>.                       //
 //                                                       //
 //-------------------------------------------------------//
 //                                                       //
@@ -167,15 +166,15 @@ CWKSP::CWKSP(wxWindow *pParent)
 	IMG_ADD_TO_NOTEBOOK(ID_IMG_NB_WKSP_MAPS);
 
 	//-----------------------------------------------------
-	m_pTools		= new CWKSP_Tool_Control	(this);
+	m_pTools		= new CWKSP_Tool_Control(this);
 
 	SUBNB_CREATE(ID_WND_WKSP_DATA, _TL("Data"));
-	m_pData			= new CWKSP_Data_Control	(pNotebook);
-	m_pData_Buttons	= new CWKSP_Data_Buttons	(pNotebook);
+	m_pData			= new CWKSP_Data_Control(pNotebook);
+	m_pData_Buttons	= new CWKSP_Data_Buttons(pNotebook);
 
 	SUBNB_CREATE(ID_WND_WKSP_MAPS, _TL("Maps"));
-	m_pMaps			= new CWKSP_Map_Control		(pNotebook);
-	m_pMaps_Buttons	= new CWKSP_Map_Buttons		(pNotebook);
+	m_pMaps			= new CWKSP_Map_Control (pNotebook);
+	m_pMaps_Buttons	= new CWKSP_Map_Buttons (pNotebook);
 }
 
 //---------------------------------------------------------
@@ -184,9 +183,9 @@ void CWKSP::Add_Pages(void)
 	long	lValue;
 
 	//-----------------------------------------------------
-	AddPage(m_pTools          , _TL("Tools"), false, IMG_TOOLS);
-	AddPage(m_pData->GetParent(), _TL("Data" ), false, IMG_DATA);
-	AddPage(m_pMaps->GetParent(), _TL("Maps" ), false, IMG_MAPS);
+	AddPage(m_pTools            , _TL("Tools"), false, IMG_TOOLS);
+	AddPage(m_pData->GetParent(), _TL("Data" ), false, IMG_DATA );
+	AddPage(m_pMaps->GetParent(), _TL("Maps" ), false, IMG_MAPS );
 
 	if( CONFIG_Read("/DATA", "TAB", lValue) )
 	{
@@ -220,7 +219,7 @@ CWKSP::~CWKSP(void)
 	CONFIG_Write("/DATA/BUTTONS", "TAB", (long)((wxNotebook *)m_pData->GetParent())->GetSelection());
 	CONFIG_Write("/MAPS/BUTTONS", "TAB", (long)((wxNotebook *)m_pMaps->GetParent())->GetSelection());
 
-	g_pWKSP		= NULL;
+	g_pWKSP	= NULL;
 }
 
 
@@ -275,14 +274,14 @@ void CWKSP::On_Page_Changed(wxNotebookEvent &event)
 //---------------------------------------------------------
 void CWKSP::On_Command(wxCommandEvent &event)
 {
-	if(	(event.GetId() >= ID_CMD_TABLES_RECENT_FIRST       && event.GetId() <= ID_CMD_TABLES_RECENT_LAST)
-	||	(event.GetId() >= ID_CMD_SHAPES_RECENT_FIRST       && event.GetId() <= ID_CMD_SHAPES_RECENT_LAST)
-	||	(event.GetId() >= ID_CMD_POINTCLOUD_RECENT_FIRST   && event.GetId() <= ID_CMD_POINTCLOUD_RECENT_LAST)
-	||	(event.GetId() >= ID_CMD_TIN_RECENT_FIRST          && event.GetId() <= ID_CMD_TIN_RECENT_LAST)
-	||	(event.GetId() >= ID_CMD_GRIDS_RECENT_FIRST        && event.GetId() <= ID_CMD_GRIDS_RECENT_LAST)
+	if(	(event.GetId() >= ID_CMD_TABLE_RECENT_FIRST        && event.GetId() <= ID_CMD_TABLE_RECENT_LAST       )
+	||	(event.GetId() >= ID_CMD_SHAPES_RECENT_FIRST       && event.GetId() <= ID_CMD_SHAPES_RECENT_LAST      )
+	||	(event.GetId() >= ID_CMD_POINTCLOUD_RECENT_FIRST   && event.GetId() <= ID_CMD_POINTCLOUD_RECENT_LAST  )
+	||	(event.GetId() >= ID_CMD_TIN_RECENT_FIRST          && event.GetId() <= ID_CMD_TIN_RECENT_LAST         )
+	||	(event.GetId() >= ID_CMD_GRID_RECENT_FIRST         && event.GetId() <= ID_CMD_GRID_RECENT_LAST        )
 	||	(event.GetId() >= ID_CMD_DATA_PROJECT_RECENT_FIRST && event.GetId() <= ID_CMD_DATA_PROJECT_RECENT_LAST) )
 	{
-		m_pData   ->On_Command(event);
+		m_pData->On_Command(event);
 	}
 	else switch( event.GetId() )
 	{
@@ -294,8 +293,8 @@ void CWKSP::On_Command(wxCommandEvent &event)
 				switch( GetCurrentPage()->GetId() )
 				{
 				case ID_WND_WKSP_TOOLS:	m_pTools->On_Command(event);	break;
-				case ID_WND_WKSP_DATA:		m_pData   ->On_Command(event);	break;
-				case ID_WND_WKSP_MAPS:		m_pMaps   ->On_Command(event);	break;
+				case ID_WND_WKSP_DATA :	m_pData ->On_Command(event);	break;
+				case ID_WND_WKSP_MAPS :	m_pMaps ->On_Command(event);	break;
 				}
 			}
 		}
@@ -306,18 +305,18 @@ void CWKSP::On_Command(wxCommandEvent &event)
 		{
 			switch( GetCurrentPage()->GetId() )
 			{
-			case ID_WND_WKSP_TOOLS:	m_pTools->On_Command(event);	break;
-			case ID_WND_WKSP_DATA:		m_pData   ->On_Command(event);	break;
-			case ID_WND_WKSP_MAPS:		m_pMaps   ->On_Command(event);	break;
+			case ID_WND_WKSP_TOOLS: m_pTools->On_Command(event);	break;
+			case ID_WND_WKSP_DATA : m_pData ->On_Command(event);	break;
+			case ID_WND_WKSP_MAPS : m_pMaps ->On_Command(event);	break;
 			}
 		}
 		break;
 
-	case ID_CMD_TOOLS_OPEN:
+	case ID_CMD_TOOL_OPEN:
 		m_pTools->On_Command(event);
 		break;
 
-	case ID_CMD_TOOLS_SEARCH:
+	case ID_CMD_TOOL_SEARCH:
 		m_pTools->On_Command(event);
 		break;
 
@@ -329,11 +328,11 @@ void CWKSP::On_Command(wxCommandEvent &event)
 	case ID_CMD_DATA_PROJECT_COPY:
 	case ID_CMD_DATA_PROJECT_COPY_DB:
 	case ID_CMD_DATA_PROJECT_BROWSE:
-	case ID_CMD_TABLES_OPEN:
+	case ID_CMD_TABLE_OPEN:
 	case ID_CMD_SHAPES_OPEN:
 	case ID_CMD_TIN_OPEN:
 	case ID_CMD_POINTCLOUD_OPEN:
-	case ID_CMD_GRIDS_OPEN:
+	case ID_CMD_GRID_OPEN:
 		m_pData->On_Command(event);
 		break;
 
@@ -351,8 +350,8 @@ void CWKSP::On_Command_UI(wxUpdateUIEvent &event)
 		if( !g_pACTIVE->Get_Active() || !g_pACTIVE->Get_Active()->On_Command_UI(event) )
 		{
 			m_pTools->On_Command_UI(event);
-			m_pData   ->On_Command_UI(event);
-			m_pMaps   ->On_Command_UI(event);
+			m_pData ->On_Command_UI(event);
+			m_pMaps ->On_Command_UI(event);
 		}
 		break;
 
@@ -362,8 +361,8 @@ void CWKSP::On_Command_UI(wxUpdateUIEvent &event)
 			switch( GetCurrentPage()->GetId() )
 			{
 			case ID_WND_WKSP_TOOLS:	m_pTools->On_Command_UI(event);	break;
-			case ID_WND_WKSP_DATA:		m_pData   ->On_Command_UI(event);	break;
-			case ID_WND_WKSP_MAPS:		m_pMaps   ->On_Command_UI(event);	break;
+			case ID_WND_WKSP_DATA :	m_pData ->On_Command_UI(event);	break;
+			case ID_WND_WKSP_MAPS :	m_pMaps ->On_Command_UI(event);	break;
 			}
 		}
 		break;
@@ -371,7 +370,7 @@ void CWKSP::On_Command_UI(wxUpdateUIEvent &event)
 	case ID_CMD_DATA_OPEN:
 		break;
 
-	case ID_CMD_TOOLS_SEARCH:
+	case ID_CMD_TOOL_SEARCH:
 		m_pTools->On_Command_UI(event);
 		break;
 
@@ -407,7 +406,7 @@ bool CWKSP::Open(void)
 {
 	wxArrayString	File_Paths;
 
-	if( DLG_Open(File_Paths, ID_DLG_WKSP_OPEN) )
+	if( DLG_Open(File_Paths, ID_DLG_FILE_OPEN) )
 	{
 		MSG_General_Add_Line();
 
@@ -425,8 +424,8 @@ bool CWKSP::Open(void)
 //---------------------------------------------------------
 bool CWKSP::Open(const wxString &File_Name)
 {
-	return(	m_pTools	->Get_Manager()->Open(File_Name)
-		||	m_pData		->Get_Manager()->Open(File_Name)
+	return(	m_pTools->Get_Manager()->Open(File_Name)
+		||  m_pData ->Get_Manager()->Open(File_Name)
 	);
 }
 
