@@ -97,8 +97,6 @@ CWKSP_Grids::CWKSP_Grids(CSG_Grids *pGrids)
 	On_Create_Parameters();
 
 	DataObject_Changed();
-
-	Fit_Colors();
 }
 
 
@@ -301,7 +299,7 @@ void CWKSP_Grids::On_Create_Parameters(void)
 
 	m_Parameters.Add_Choice("NODE_DISPLAY", "DISPLAY_RESAMPLING", _TL("Resampling"),
 		_TL(""),
-		CSG_String::Format("%s|%s|%s|%s|",
+		CSG_String::Format("%s|%s|%s|%s",
 			_TL("Nearest Neighbour"),
 			_TL("Bilinear Interpolation"),
 			_TL("Bicubic Spline Interpolation"),
@@ -312,26 +310,14 @@ void CWKSP_Grids::On_Create_Parameters(void)
 	//-----------------------------------------------------
 	// Classification...
 
-	m_Parameters.Add_Node("NODE_COLORS", "NODE_OVERLAY", _TL("RGB Composite"),
-		_TL("")
-	);
+	CSG_String	List(_Get_List_Bands());
 
-	m_Parameters.Add_Choice("NODE_OVERLAY",
-		"OVERLAY_STATISTICS", _TL("Statistics"),
-		_TL(""),
-		CSG_String::Format("%s|%s",
-			_TL("all bands"),
-			_TL("each band")
-		), 1
-	);
+	m_Parameters["BAND_R"].asChoice()->Set_Items(List); m_Parameters["BAND_R"].Set_Value(0);
+	m_Parameters["BAND_G"].asChoice()->Set_Items(List); m_Parameters["BAND_G"].Set_Value(1);
+	m_Parameters["BAND_B"].asChoice()->Set_Items(List); m_Parameters["BAND_B"].Set_Value(2);
 
-	m_Parameters.Add_Choice("NODE_OVERLAY", "BAND_R", _TL("Red"  ), _TL(""), _Get_List_Bands(), 0);
-	m_Parameters.Add_Choice("NODE_OVERLAY", "BAND_G", _TL("Green"), _TL(""), _Get_List_Bands(), 1);
-	m_Parameters.Add_Choice("NODE_OVERLAY", "BAND_B", _TL("Blue" ), _TL(""), _Get_List_Bands(), 2);
-
-//	m_Parameters.Add_Range("BAND_R", "BAND_R_RANGE", _TL("Value Range"), _TL(""));
-//	m_Parameters.Add_Range("BAND_G", "BAND_G_RANGE", _TL("Value Range"), _TL(""));
-//	m_Parameters.Add_Range("BAND_B", "BAND_B_RANGE", _TL("Value Range"), _TL(""));
+	//-----------------------------------------------------
+	m_Fit_Colors	= g_pData->Get_Parameter("GRID_STRETCH_DEFAULT")->asInt();
 }
 
 
@@ -342,7 +328,9 @@ void CWKSP_Grids::On_Create_Parameters(void)
 //---------------------------------------------------------
 CSG_Grid * CWKSP_Grids::Get_Grid(void)
 {
-	return( Get_Grids()->Get_Grid_Ptr(m_Parameters("BAND")->asInt()) );
+	int	i	= m_Parameters("BAND")->asInt();
+
+	return( i >= 0 && i < Get_Grids()->Get_NZ() ? Get_Grids()->Get_Grid_Ptr(i) : NULL );
 }
 
 //---------------------------------------------------------
@@ -407,20 +395,21 @@ CSG_String CWKSP_Grids::_Get_List_Bands(int Attribute)
 //---------------------------------------------------------
 void CWKSP_Grids::On_DataObject_Changed(void)
 {
-	CWKSP_Layer::On_DataObject_Changed();
-
 	//-----------------------------------------------------
 	m_Edit_Attributes.Create(Get_Grids()->Get_Attributes());
 
 	//-----------------------------------------------------
-	m_Parameters("OBJECT_Z_UNIT"  )->Set_Value(Get_Grids()->Get_Unit   ());
-	m_Parameters("OBJECT_Z_FACTOR")->Set_Value(Get_Grids()->Get_Scaling());
-	m_Parameters("OBJECT_Z_OFFSET")->Set_Value(Get_Grids()->Get_Offset ());
+	m_Parameters.Set_Parameter("OBJECT_Z_UNIT"  , Get_Grids()->Get_Unit   ());
+	m_Parameters.Set_Parameter("OBJECT_Z_FACTOR", Get_Grids()->Get_Scaling());
+	m_Parameters.Set_Parameter("OBJECT_Z_OFFSET", Get_Grids()->Get_Offset ());
+
+	m_Parameters.Set_Parameter("MAX_SAMPLES"    , 100. * Get_Grids()->Get_Max_Samples() / (double)Get_Grids()->Get_NCells());
 
 	//-----------------------------------------------------
-	m_Parameters("MAX_SAMPLES")->Set_Value(
-		100.0 * (double)Get_Grids()->Get_Max_Samples() / (double)Get_Grids()->Get_NCells()
-	);
+	if( m_Parameters("STRETCH_DEFAULT")->asInt() >= 3 )	// manual
+	{
+		m_Parameters.Set_Parameter("STRETCH_DEFAULT", m_Fit_Colors);
+	}
 
 	//-----------------------------------------------------
 	CSG_String	List;
@@ -440,6 +429,22 @@ void CWKSP_Grids::On_DataObject_Changed(void)
 	m_Parameters("BAND_R")->asChoice()->Set_Items(List);
 	m_Parameters("BAND_G")->asChoice()->Set_Items(List);
 	m_Parameters("BAND_B")->asChoice()->Set_Items(List);
+
+	if( m_Parameters("BAND_R")->asInt() == 0
+	&&  m_Parameters("BAND_G")->asInt() == 0
+	&&  m_Parameters("BAND_B")->asInt() == 0 )
+	{
+		m_Parameters.Set_Parameter("BAND_G", 1);
+		m_Parameters.Set_Parameter("BAND_B", 2);
+	}
+
+	ColorsParms_Adjust(m_Parameters);
+	ColorsParms_Adjust(m_Parameters, Get_Grid(0), "_R");
+	ColorsParms_Adjust(m_Parameters, Get_Grid(1), "_G");
+	ColorsParms_Adjust(m_Parameters, Get_Grid(2), "_B");
+
+	//-----------------------------------------------------
+	CWKSP_Layer::On_DataObject_Changed();
 }
 
 //---------------------------------------------------------
@@ -449,14 +454,10 @@ void CWKSP_Grids::On_Parameters_Changed(void)
 
 	//-----------------------------------------------------
 	Get_Grids()->Set_Unit   (m_Parameters("OBJECT_Z_UNIT"  )->asString());
-	Get_Grids()->Set_Scaling(m_Parameters("OBJECT_Z_FACTOR")->asDouble(), m_Parameters("OBJECT_Z_OFFSET")->asDouble());
+	Get_Grids()->Set_Scaling(m_Parameters("OBJECT_Z_FACTOR")->asDouble(),
+	                         m_Parameters("OBJECT_Z_OFFSET")->asDouble());
 
-	Get_Grids()->Set_Max_Samples(Get_Grid()->Get_NCells() * (m_Parameters("MAX_SAMPLES")->asDouble() / 100.0) );
-
-	if( m_Parameters("COLORS_TYPE")->asInt() == CLASSIFY_OVERLAY && m_Parameters("OVERLAY_STATISTICS")->asInt() != 0 )
-	{
-		_Fit_Colors();
-	}
+	Get_Grids()->Set_Max_Samples(Get_Grids()->Get_NCells() * (m_Parameters("MAX_SAMPLES")->asDouble() / 100.) * (Get_Grids()->Get_NZ() < 1 ? 1. : 1. / Get_Grids()->Get_NZ()));
 
 	//-----------------------------------------------------
 	Get_Grids()->Set_Z_Attribute(m_Parameters("DIM_ATTRIBUTE")->asInt());
@@ -472,6 +473,34 @@ void CWKSP_Grids::On_Parameters_Changed(void)
 		m_Parameters("BAND_G")->asChoice()->Set_Items(List);
 		m_Parameters("BAND_B")->asChoice()->Set_Items(List);
 	}
+
+	//-----------------------------------------------------
+	m_Classify[0].Set_Metric(
+		m_Parameters("METRIC_SCALE_MODE"  )->asInt   (),
+		m_Parameters("METRIC_SCALE_LOG"   )->asDouble(),
+		m_Parameters("METRIC_ZRANGE_R.MIN")->asDouble(),
+		m_Parameters("METRIC_ZRANGE_R.MAX")->asDouble()
+	);
+
+	m_Classify[1].Set_Metric(
+		m_Parameters("METRIC_SCALE_MODE"  )->asInt   (),
+		m_Parameters("METRIC_SCALE_LOG"   )->asDouble(),
+		m_Parameters("METRIC_ZRANGE_G.MIN")->asDouble(),
+		m_Parameters("METRIC_ZRANGE_G.MAX")->asDouble()
+	);
+
+	m_Classify[2].Set_Metric(
+		m_Parameters("METRIC_SCALE_MODE"  )->asInt   (),
+		m_Parameters("METRIC_SCALE_LOG"   )->asDouble(),
+		m_Parameters("METRIC_ZRANGE_B.MIN")->asDouble(),
+		m_Parameters("METRIC_ZRANGE_B.MAX")->asDouble()
+	);
+
+	//-----------------------------------------------------
+	if( m_Parameters("STRETCH_DEFAULT")->asInt() < 3 )	// not manual, remember last state...
+	{
+		m_Fit_Colors	= m_Parameters("STRETCH_DEFAULT")->asInt();
+	}
 }
 
 //---------------------------------------------------------
@@ -492,8 +521,6 @@ bool CWKSP_Grids::Edit_Set_Attributes(void)
 	{
 		DataObject_Changed();
 
-	//	_Fit_Colors(true); Update_Views(true);
-
 		return( true );
 	}
 
@@ -508,10 +535,12 @@ bool CWKSP_Grids::Edit_Set_Attributes(void)
 //---------------------------------------------------------
 int CWKSP_Grids::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *pParameter, int Flags)
 {
+	int		Type	= (*pParameters)("COLORS_TYPE")->asInt();
+
 	//-----------------------------------------------------
 	if( Flags & PARAMETER_CHECK_VALUES )
 	{
-		if(	pParameter->Cmp_Identifier("OBJECT_Z_FACTOR")
+		if( pParameter->Cmp_Identifier("OBJECT_Z_FACTOR")
 		||  pParameter->Cmp_Identifier("OBJECT_Z_OFFSET") )
 		{
 			double	newFactor	= (*pParameters)("OBJECT_Z_FACTOR")->asDouble(), oldFactor	= m_Parameters("OBJECT_Z_FACTOR")->asDouble();
@@ -527,7 +556,7 @@ int CWKSP_Grids::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter
 			}
 		}
 
-		if(	pParameter->Cmp_Identifier("DIM_NAME") )
+		if( pParameter->Cmp_Identifier("DIM_NAME") )
 		{
 			CSG_String	List	= _Get_List_Bands(pParameter->asInt());
 
@@ -537,28 +566,32 @@ int CWKSP_Grids::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter
 			(*pParameters)("BAND_B")->asChoice()->Set_Items(List);
 		}
 
-		if( (*pParameters)("COLORS_TYPE")->asInt() == CLASSIFY_METRIC
-		||  (*pParameters)("COLORS_TYPE")->asInt() == CLASSIFY_GRADUATED
-		||  (*pParameters)("COLORS_TYPE")->asInt() == CLASSIFY_OVERLAY )
+		if( Type == CLASSIFY_OVERLAY && (*pParameters)["OVERLAY_FIT"].asInt() == 1
+		&& (pParameter->Cmp_Identifier("STRETCH_DEFAULT")
+		||  pParameter->Cmp_Identifier("STRETCH_LINEAR" )
+		||  pParameter->Cmp_Identifier("STRETCH_STDDEV" )
+		||  pParameter->Cmp_Identifier("STRETCH_INRANGE")
+		||  pParameter->Cmp_Identifier("STRETCH_PCTL"   )
+		||  pParameter->Cmp_Identifier("OVERLAY_FIT")
+		||  pParameter->Cmp_Identifier("BAND_R")
+		||  pParameter->Cmp_Identifier("BAND_G")
+		||  pParameter->Cmp_Identifier("BAND_B") ) )
 		{
-			if(	pParameter->Cmp_Identifier("BAND"              )
-			||  pParameter->Cmp_Identifier("BAND_R"            )
-			||  pParameter->Cmp_Identifier("BAND_G"            )
-			||  pParameter->Cmp_Identifier("BAND_B"            )
-			||  pParameter->Cmp_Identifier("OVERLAY_STATISTICS")
-			||  pParameter->Cmp_Identifier("COLORS_TYPE"       )
-			||  pParameter->Cmp_Identifier("STRETCH_DEFAULT"   )
-			||  pParameter->Cmp_Identifier("STRETCH_LINEAR"    )
-			||  pParameter->Cmp_Identifier("STRETCH_STDDEV"    )
-			||  pParameter->Cmp_Identifier("STRETCH_INRANGE"   )
-			||  pParameter->Cmp_Identifier("STRETCH_PCTL"      ) )
+			int	i;
+			
+			if( (i = (*pParameters)("BAND_R")->asInt()) >= 0 && i < Get_Grids()->Get_NZ() )
 			{
-				double	Minimum, Maximum;
+				ColorsParms_Adjust(*pParameters, Get_Grids()->Get_Grid_Ptr(i), "_R");
+			}
 
-				if( _Fit_Colors(*pParameters, Minimum, Maximum) )
-				{
-					(*pParameters)("METRIC_ZRANGE")->asRange()->Set_Range(Minimum, Maximum);
-				}
+			if( (i = (*pParameters)("BAND_G")->asInt()) >= 0 && i < Get_Grids()->Get_NZ() )
+			{
+				ColorsParms_Adjust(*pParameters, Get_Grids()->Get_Grid_Ptr(i), "_G");
+			}
+
+			if( (i = (*pParameters)("BAND_B")->asInt()) >= 0 && i < Get_Grids()->Get_NZ() )
+			{
+				ColorsParms_Adjust(*pParameters, Get_Grids()->Get_Grid_Ptr(i), "_B");
 			}
 		}
 	}
@@ -567,28 +600,26 @@ int CWKSP_Grids::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter
 	if( Flags & PARAMETER_CHECK_ENABLE )
 	{
 		if( pParameter->Cmp_Identifier("COLORS_TYPE")
-		||  pParameter->Cmp_Identifier("OVERLAY_STATISTICS") )
+		||  pParameter->Cmp_Identifier("OVERLAY_FIT") )
 		{
-			int		Type	= (*pParameters)("COLORS_TYPE")->asInt();
+			pParameters->Set_Enabled("DISPLAY_RESAMPLING", Type != CLASSIFY_LUT && Type != CLASSIFY_UNIQUE);
 
 			pParameters->Set_Enabled("NODE_UNISYMBOL"    , Type == CLASSIFY_UNIQUE);
 			pParameters->Set_Enabled("NODE_LUT"          , Type == CLASSIFY_LUT);
 			pParameters->Set_Enabled("NODE_METRIC"       , Type != CLASSIFY_UNIQUE && Type != CLASSIFY_LUT);
-			pParameters->Set_Enabled("NODE_OVERLAY"      , Type == CLASSIFY_OVERLAY);
 
 			pParameters->Set_Enabled("BAND"              , Type == CLASSIFY_METRIC || Type == CLASSIFY_GRADUATED || Type == CLASSIFY_LUT);
 
-			pParameters->Set_Enabled("METRIC_ZRANGE"     , Type == CLASSIFY_METRIC || Type == CLASSIFY_GRADUATED || (Type == CLASSIFY_OVERLAY && (*pParameters)("OVERLAY_STATISTICS")->asInt() == 0));
+			pParameters->Set_Enabled("METRIC_ZRANGE"     , Type == CLASSIFY_METRIC || Type == CLASSIFY_GRADUATED || (Type == CLASSIFY_OVERLAY && (*pParameters)["OVERLAY_FIT"].asInt() == 0));
 			pParameters->Set_Enabled("METRIC_SCALE_MODE" , Type == CLASSIFY_METRIC || Type == CLASSIFY_GRADUATED ||  Type == CLASSIFY_OVERLAY);
 
-			pParameters->Set_Enabled("DISPLAY_RESAMPLING", Type != CLASSIFY_LUT && Type != CLASSIFY_UNIQUE);
-		}
-
-		if(	pParameter->Cmp_Identifier("STRETCH_DEFAULT") )
-		{
-			pParameters->Set_Enabled("STRETCH_LINEAR", pParameter->asInt() == 0);
-			pParameters->Set_Enabled("STRETCH_STDDEV", pParameter->asInt() == 1);
-			pParameters->Set_Enabled("STRETCH_PCTL"  , pParameter->asInt() == 2);
+			pParameters->Set_Enabled("BAND_R"            , Type == CLASSIFY_OVERLAY);
+			pParameters->Set_Enabled("BAND_G"            , Type == CLASSIFY_OVERLAY);
+			pParameters->Set_Enabled("BAND_B"            , Type == CLASSIFY_OVERLAY);
+			pParameters->Set_Enabled("OVERLAY_FIT"       , Type == CLASSIFY_OVERLAY);
+			pParameters->Set_Enabled("METRIC_ZRANGE_R"   , Type == CLASSIFY_OVERLAY && (*pParameters)["OVERLAY_FIT"].asInt() == 1);
+			pParameters->Set_Enabled("METRIC_ZRANGE_G"   , Type == CLASSIFY_OVERLAY && (*pParameters)["OVERLAY_FIT"].asInt() == 1);
+			pParameters->Set_Enabled("METRIC_ZRANGE_B"   , Type == CLASSIFY_OVERLAY && (*pParameters)["OVERLAY_FIT"].asInt() == 1);
 		}
 	}
 
@@ -611,7 +642,7 @@ void CWKSP_Grids::_LUT_Create(void)
 		Parameters.Create(NULL, _TL("Classify"), _TL(""));
 		Parameters.Add_Colors("", "COLOR" , _TL("Colors"        ), _TL(""))->asColors()->Set_Count(11);
 		Parameters.Add_Choice("", "METHOD", _TL("Classification"), _TL(""),
-			CSG_String::Format("%s|%s|%s|%s|",
+			CSG_String::Format("%s|%s|%s|%s",
 				_TL("unique values"),
 				_TL("equal intervals"),
 				_TL("quantiles"),
@@ -639,11 +670,11 @@ void CWKSP_Grids::_LUT_Create(void)
 
 		#define MAX_CLASSES	1024
 
-		for(sLong iCell = 0; iCell<Get_Grid()->Get_NCells() && s.Get_Count()<MAX_CLASSES && PROGRESSBAR_Set_Position(iCell, Get_Grid()->Get_NCells()); iCell++)
+		for(sLong iCell = 0; iCell<Get_Grids()->Get_NCells() && s.Get_Count()<MAX_CLASSES && PROGRESSBAR_Set_Position(iCell, Get_Grids()->Get_NCells()); iCell++)
 		{
-			if( !Get_Grid()->is_NoData(iCell) )
+			if( !Get_Grids()->is_NoData(iCell) )
 			{
-				s	+= Get_Grid()->asDouble(iCell);
+				s	+= Get_Grids()->asDouble(iCell);
 			}
 		}
 
@@ -669,16 +700,16 @@ void CWKSP_Grids::_LUT_Create(void)
 
 	//-----------------------------------------------------
 	case 1:	// equal intervals
-		if( Get_Grid()->Get_Range() && Colors.Get_Count() > 0 )
+		if( Get_Grids()->Get_Range() && Colors.Get_Count() > 0 )
 		{
 			double	Minimum, Maximum, Interval;
 
-			Interval	= Get_Grid()->Get_Range() / (double)Colors.Get_Count();
-			Minimum		= Get_Grid()->Get_Min  ();
+			Interval	= Get_Grids()->Get_Range() / (double)Colors.Get_Count();
+			Minimum		= Get_Grids()->Get_Min  ();
 
 			for(int iClass=0; iClass<Colors.Get_Count(); iClass++, Minimum+=Interval)
 			{
-				Maximum	= iClass < Colors.Get_Count() - 1 ? Minimum + Interval : Get_Grid()->Get_Max() + 1.0;
+				Maximum	= iClass < Colors.Get_Count() - 1 ? Minimum + Interval : Get_Grids()->Get_Max() + 1.0;
 
 				CSG_String	Name	= SG_Get_String(Minimum, -2)
 							+ " - " + SG_Get_String(Maximum, -2);
@@ -697,34 +728,19 @@ void CWKSP_Grids::_LUT_Create(void)
 	//-----------------------------------------------------
 	case 2:	// quantiles
 		{
-			if( Get_Grid()->Get_NCells() < Colors.Get_Count() )
+			if( Get_Grids()->Get_NCells() < Colors.Get_Count() )
 			{
-				Colors.Set_Count(Get_Grid()->Get_NCells());
+				Colors.Set_Count(Get_Grids()->Get_NCells());
 			}
 
-			sLong	jCell, nCells;
-			double	Minimum, Maximum, iCell, Count;
+			double	Minimum, Maximum	= Get_Grids()->Get_Histogram().Get_Quantile(0.0);
 
-			Maximum	= Get_Grid()->Get_Min();
-			nCells	= Get_Grid()->Get_NCells() - Get_Grid()->Get_NoData_Count();
-			iCell	= Count	= nCells / (double)Colors.Get_Count();
+			double	Step	= 1. / Colors.Get_Count();
 
-			for(iCell=0.0; iCell<Get_Grid()->Get_NCells(); iCell++)
+			for(int iClass=0; iClass<Colors.Get_Count(); iClass++)
 			{
-				if( Get_Grid()->Get_Sorted(iCell, jCell, false) )
-				{
-					break;
-				}
-			}
-
-			iCell	+= Count;
-
-			for(int iClass=0; iClass<Colors.Get_Count(); iClass++, iCell+=Count)
-			{
-				Get_Grid()->Get_Sorted(iCell, jCell, false);
-
 				Minimum	= Maximum;
-				Maximum	= iCell < Get_Grid()->Get_NCells() ? Get_Grid()->asDouble(jCell) : Get_Grid()->Get_Max() + 1.0;
+				Maximum	= Get_Grids()->Get_Histogram().Get_Quantile((1. + iClass) / Colors.Get_Count());
 
 				CSG_String	Name	= SG_Get_String(Minimum, -2)
 							+ " - " + SG_Get_String(Maximum, -2);
@@ -743,7 +759,7 @@ void CWKSP_Grids::_LUT_Create(void)
 	//-----------------------------------------------------
 	case 3:	// natural breaks
 		{
-			CSG_Natural_Breaks	Breaks(Get_Grid(), Colors.Get_Count(), 255);
+			CSG_Natural_Breaks	Breaks(Get_Grids(), Colors.Get_Count(), 255);
 
 			if( Breaks.Get_Count() <= Colors.Get_Count() ) return;
 
@@ -788,47 +804,52 @@ void CWKSP_Grids::_LUT_Create(void)
 //---------------------------------------------------------
 wxString CWKSP_Grids::Get_Value(CSG_Point ptWorld, double Epsilon)
 {
-	wxString	s;	double	Value;
+	wxString	s;
 
-	switch( m_pClassify->Get_Mode() )
+	if( Get_Grid() )
 	{
-	default:
-		break;
+		double	Value;
 
-	case CLASSIFY_METRIC:
-	case CLASSIFY_GRADUATED:
-		if( Get_Grid()->Get_Value(ptWorld, Value, GRID_RESAMPLING_NearestNeighbour) )
+		switch( m_pClassify->Get_Mode() )
 		{
-			s	= SG_Get_String(Value, -12).c_str();
-
-			if( Get_Grids()->Get_Unit() && *Get_Grids()->Get_Unit() )
+		case CLASSIFY_METRIC:
+		case CLASSIFY_GRADUATED:
+			if( Get_Grid()->Get_Value(ptWorld, Value, GRID_RESAMPLING_NearestNeighbour) )
 			{
-				s += " "; s += Get_Grids()->Get_Unit();
+				s	= SG_Get_String(Value, -12).c_str();
+
+				if( Get_Grids()->Get_Unit() && *Get_Grids()->Get_Unit() )
+				{
+					s += " "; s += Get_Grids()->Get_Unit();
+				}
 			}
-		}
-		break;
+			break;
 
-	case CLASSIFY_OVERLAY:
-		if( Get_Grid(0)->Get_Value(ptWorld, Value, GRID_RESAMPLING_NearestNeighbour) )
-		{
-			s	+= wxString::Format("R%s ", SG_Get_String(Value, -12).c_str());
-		}
-		if( Get_Grid(1)->Get_Value(ptWorld, Value, GRID_RESAMPLING_NearestNeighbour) )
-		{
-			s	+= wxString::Format("G%s ", SG_Get_String(Value, -12).c_str());
-		}
-		if( Get_Grid(2)->Get_Value(ptWorld, Value, GRID_RESAMPLING_NearestNeighbour) )
-		{
-			s	+= wxString::Format("B%s ", SG_Get_String(Value, -12).c_str());
-		}
-		break;
+		case CLASSIFY_OVERLAY:
+			if( Get_Grid(0)->Get_Value(ptWorld, Value, GRID_RESAMPLING_NearestNeighbour) )
+			{
+				s	+= wxString::Format("R%s ", SG_Get_String(Value, -6).c_str());
+			}
+			if( Get_Grid(1)->Get_Value(ptWorld, Value, GRID_RESAMPLING_NearestNeighbour) )
+			{
+				s	+= wxString::Format("G%s ", SG_Get_String(Value, -6).c_str());
+			}
+			if( Get_Grid(2)->Get_Value(ptWorld, Value, GRID_RESAMPLING_NearestNeighbour) )
+			{
+				s	+= wxString::Format("B%s ", SG_Get_String(Value, -6).c_str());
+			}
+			break;
 
-	case CLASSIFY_LUT:
-		if( Get_Grid()->Get_Value(ptWorld, Value, GRID_RESAMPLING_NearestNeighbour) )
-		{
-			s	= m_pClassify->Get_Class_Name_byValue(Value);
+		case CLASSIFY_LUT:
+			if( Get_Grid()->Get_Value(ptWorld, Value, GRID_RESAMPLING_NearestNeighbour) )
+			{
+				s	= m_pClassify->Get_Class_Name_byValue(Value);
+			}
+			break;
+
+		default:
+			break;
 		}
-		break;
 	}
 
 	return( s );
@@ -844,116 +865,37 @@ double CWKSP_Grids::Get_Value_StdDev (void)	{	return( ((CSG_Grids *)m_pObject)->
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
-//---------------------------------------------------------
-bool CWKSP_Grids::Fit_Colors(void)
-{
-	CSG_String	List	= _Get_List_Bands();
-
-	m_Parameters("BAND"  )->asChoice()->Set_Items(List);
-	m_Parameters("BAND_R")->asChoice()->Set_Items(List);
-	m_Parameters("BAND_G")->asChoice()->Set_Items(List);
-	m_Parameters("BAND_B")->asChoice()->Set_Items(List);
-
-	return( _Fit_Colors() );
-}
-
-//---------------------------------------------------------
-bool CWKSP_Grids::_Fit_Colors(bool bRefresh)
-{
-	if( Get_Grids()->Get_NZ() <= 0 )
-	{
-		return( false );
-	}
-
-	if( m_Parameters("COLORS_TYPE")->asInt() == CLASSIFY_METRIC
-	||  m_Parameters("COLORS_TYPE")->asInt() == CLASSIFY_GRADUATED )
-	{
-		double	Minimum, Maximum;
-
-		return( _Fit_Colors(m_Parameters, Minimum, Maximum) && Set_Color_Range(Minimum, Maximum) );
-	}
-
-	if( m_Parameters("COLORS_TYPE")->asInt() == CLASSIFY_OVERLAY )
-	{
-		if( m_Parameters("STRETCH_DEFAULT")->asInt() != 2 )	// no quantiles
-		{
-			CSG_Simple_Statistics	s;
-
-			if( m_Parameters("OVERLAY_STATISTICS")->asInt() == 0 )	// overall band statistics
-			{
-				if( s.Create(Get_Grids()->Get_Statistics()) && _Fit_Colors(s, m_pClassify) )
-				{
-					return( !bRefresh || Update_Views() );
-				}
-			}
-			else	// band wise statistics
-			{
-				if( s.Create(Get_Grid(0)->Get_Statistics()) && _Fit_Colors(s, &m_Classify[0])
-				&&  s.Create(Get_Grid(1)->Get_Statistics()) && _Fit_Colors(s, &m_Classify[1])
-				&&  s.Create(Get_Grid(2)->Get_Statistics()) && _Fit_Colors(s, &m_Classify[2]) )
-				{
-					return( !bRefresh || Update_Views() );
-				}
-			}
-		}
-		else // quantiles
-		{
-			int		Mode	= m_Parameters("METRIC_SCALE_MODE")->asInt   ();
-			double	Log		= m_Parameters("METRIC_SCALE_LOG" )->asDouble();
-			double	d		= m_Parameters("STRETCH_PCTL"     )->asDouble();
-
-			if( m_Parameters("OVERLAY_STATISTICS")->asInt() == 0 )	// overall band statistics
-			{
-				m_pClassify->Set_Metric(Mode, Log, Get_Grids()->Get_Quantile(d), Get_Grids()->Get_Quantile(100 - d));
-			}
-			else	// band wise statistics
-			{
-				m_Classify[0].Set_Metric(Mode, Log, Get_Grid(0)->Get_Quantile(d), Get_Grid(0)->Get_Quantile(100 - d));
-				m_Classify[1].Set_Metric(Mode, Log, Get_Grid(1)->Get_Quantile(d), Get_Grid(1)->Get_Quantile(100 - d));
-				m_Classify[2].Set_Metric(Mode, Log, Get_Grid(2)->Get_Quantile(d), Get_Grid(2)->Get_Quantile(100 - d));
-			}
-
-			return( !bRefresh || Update_Views() );
-		}
-	}
-
-	return( false );
-}
-
 //---------------------------------------------------------
 bool CWKSP_Grids::Fit_Colors(const CSG_Rect &rWorld)
 {
-	CSG_Simple_Statistics	s;
-
-	int	Method	= m_Parameters("STRETCH_DEFAULT")->asInt();	// == 2 >> fit to quantiles
-
 	if( m_Parameters("COLORS_TYPE")->asInt() == CLASSIFY_METRIC
 	||  m_Parameters("COLORS_TYPE")->asInt() == CLASSIFY_GRADUATED )
 	{
-		return( Get_Grid()->Get_Statistics(rWorld, s, Method == 2) && _Fit_Colors(s, m_pClassify, true) );
+		if( _Fit_Colors(rWorld, Get_Grid(), m_pClassify) )
+		{
+			return( Update_Views() );
+		}
 	}
 
-	if( m_Parameters("COLORS_TYPE")->asInt() == CLASSIFY_OVERLAY )
+	if( m_Parameters("COLORS_TYPE")->asInt() == CLASSIFY_OVERLAY
+	&&  m_Parameters("OVERLAY_FIT")->asInt() == 0 )	// overall band statistics
 	{
-		if( m_Parameters("OVERLAY_STATISTICS")->asInt() == 0 )	// overall band statistics
+		if( _Fit_Colors(rWorld, Get_Grids(), m_pClassify) )
 		{
-			if( Get_Grids()->Get_Statistics(rWorld, s, Method == 2) && _Fit_Colors(s, m_pClassify) )
-			{
-				return( Update_Views() );
-			}
+			return( Update_Views() );
 		}
-		else	// band wise statistics
+	}
+
+	if( m_Parameters("COLORS_TYPE")->asInt() == CLASSIFY_OVERLAY
+	&&  m_Parameters("OVERLAY_FIT")->asInt() != 0 )	// band wise statistics
+	{
+		if( _Fit_Colors(rWorld, Get_Grid(0), &m_Classify[0], "_R")
+		&&  _Fit_Colors(rWorld, Get_Grid(1), &m_Classify[1], "_G")
+		&&  _Fit_Colors(rWorld, Get_Grid(2), &m_Classify[2], "_B") )
 		{
-			if( Get_Grid(0)->Get_Statistics(rWorld, s, Method == 2) && _Fit_Colors(s, &m_Classify[0])
-			&&  Get_Grid(1)->Get_Statistics(rWorld, s, Method == 2) && _Fit_Colors(s, &m_Classify[1])
-			&&  Get_Grid(2)->Get_Statistics(rWorld, s, Method == 2) && _Fit_Colors(s, &m_Classify[2]) )
-			{
-				return( Update_Views() );
-			}
+			return( Update_Views() );
 		}
 	}
 
@@ -961,94 +903,51 @@ bool CWKSP_Grids::Fit_Colors(const CSG_Rect &rWorld)
 }
 
 //---------------------------------------------------------
-bool CWKSP_Grids::_Fit_Colors(CSG_Parameters &Parameters, double &Minimum, double &Maximum)
+bool CWKSP_Grids::_Fit_Colors(const CSG_Rect &rWorld, CSG_Data_Object *pObject, CWKSP_Layer_Classify *pClassify, const CSG_String &Suffix)
 {
-	if( Parameters("COLORS_TYPE")->asInt() == CLASSIFY_OVERLAY )
-	{
-		CSG_Grids	*pGrids	= Get_Grids();
-
-		switch( Parameters("STRETCH_DEFAULT")->asInt() )
-		{
-		default: {	double	d	= Parameters("STRETCH_LINEAR")->asDouble() * 0.01 * pGrids->Get_Range();
-			Minimum	= pGrids->Get_Min() + d;
-			Maximum	= pGrids->Get_Max() - d;
-			break;	}
-
-		case  1: {	double	d	= Parameters("STRETCH_STDDEV")->asDouble() * pGrids->Get_StdDev();
-			Minimum	= pGrids->Get_Mean() - d; if( Parameters("STRETCH_INRANGE")->asBool() && Minimum < pGrids->Get_Min() ) Minimum = pGrids->Get_Min();
-			Maximum	= pGrids->Get_Mean() + d; if( Parameters("STRETCH_INRANGE")->asBool() && Maximum > pGrids->Get_Max() ) Maximum = pGrids->Get_Max();
-			break;	}
-
-		case  2: {	double	d	= Parameters("STRETCH_PCTL")->asDouble();
-			Minimum	= pGrids->Get_Quantile(      d);
-			Maximum	= pGrids->Get_Quantile(100 - d);
-			break;	}
-		}
-	}
-	else
-	{
-		CSG_Grid	*pGrid	= Get_Grids()->Get_Grid_Ptr(Parameters("BAND")->asInt());
-
-		switch( Parameters("STRETCH_DEFAULT")->asInt() )
-		{
-		default: {	double	d	= Parameters("STRETCH_LINEAR")->asDouble() * 0.01 * pGrid->Get_Range();
-			Minimum	= pGrid->Get_Min() + d;
-			Maximum	= pGrid->Get_Max() - d;
-			break;	}
-
-		case  1: {	double	d	= Parameters("STRETCH_STDDEV")->asDouble() * pGrid->Get_StdDev();
-			Minimum	= pGrid->Get_Mean() - d; if( Parameters("STRETCH_INRANGE")->asBool() && Minimum < pGrid->Get_Min() ) Minimum = pGrid->Get_Min();
-			Maximum	= pGrid->Get_Mean() + d; if( Parameters("STRETCH_INRANGE")->asBool() && Maximum > pGrid->Get_Max() ) Maximum = pGrid->Get_Max();
-			break;	}
-
-		case  2: {	double	d	= Parameters("STRETCH_PCTL")->asDouble();
-			Minimum	= pGrid->Get_Quantile(      d);
-			Maximum	= pGrid->Get_Quantile(100 - d);
-			break;	}
-		}
-	}
-
-	return( true );
-}
-
-//---------------------------------------------------------
-bool CWKSP_Grids::_Fit_Colors(CSG_Simple_Statistics &s, CWKSP_Layer_Classify *pClassify, bool bRefresh)
-{
-	if( s.Get_Count() <= 0 )
-	{
-		return( false );
-	}
+	#define	GET_STAT (pObject->Get_ObjectType() == SG_DATAOBJECT_TYPE_Grid ? ((CSG_Grid *)pObject)->Get_Statistics(rWorld, s) : ((CSG_Grids *)pObject)->Get_Statistics(rWorld, s))
+	#define	GET_HIST (pObject->Get_ObjectType() == SG_DATAOBJECT_TYPE_Grid ? ((CSG_Grid *)pObject)->Get_Histogram (rWorld, h) : ((CSG_Grids *)pObject)->Get_Histogram (rWorld, h))
 
 	double	Minimum, Maximum;
 
-	switch( m_Parameters("STRETCH_DEFAULT")->asInt() )
+	switch( m_Fit_Colors )
 	{
-	default: {	double	d	= m_Parameters("STRETCH_LINEAR")->asDouble() * 0.01 * s.Get_Range();
+	default: {	CSG_Simple_Statistics	s;	if( !GET_STAT )	return( false );
+		double	d	= m_Parameters("STRETCH_LINEAR")->asDouble() * 0.01 * s.Get_Range();
 		Minimum	= s.Get_Minimum() + d;
 		Maximum	= s.Get_Maximum() - d;
 		break;	}
 
-	case  1: {	double	d	= m_Parameters("STRETCH_STDDEV")->asDouble() * s.Get_StdDev();
+	case  1: {	CSG_Simple_Statistics	s;	if( !GET_STAT )	return( false );
+		double	d	= m_Parameters("STRETCH_STDDEV")->asDouble() * s.Get_StdDev();
 		Minimum	= s.Get_Mean() - d; if( m_Parameters("STRETCH_INRANGE")->asBool() && Minimum < s.Get_Minimum() ) Minimum = s.Get_Minimum();
 		Maximum	= s.Get_Mean() + d; if( m_Parameters("STRETCH_INRANGE")->asBool() && Maximum > s.Get_Maximum() ) Maximum = s.Get_Maximum();
 		break;	}
 
-	case  2: {	double	d	= m_Parameters("STRETCH_PCTL")->asDouble();
-		Minimum	= s.Get_Quantile(      d);
-		Maximum	= s.Get_Quantile(100 - d);
+	case  2: {	CSG_Histogram			h;	if( !GET_HIST ) return( false );
+		double	d	= m_Parameters("STRETCH_PCTL")->asDouble() * 0.01;
+		Minimum	= h.Get_Quantile(    d);
+		Maximum	= h.Get_Quantile(1 - d);
 		break;	}
 	}
 
-	pClassify->Set_Metric(m_Parameters("METRIC_SCALE_MODE")->asInt(), m_Parameters("METRIC_SCALE_LOG")->asDouble(), Minimum, Maximum);
+	m_Parameters.Set_Parameter("STRETCH_DEFAULT", 3);	// manual
 
-	return( !bRefresh || Set_Color_Range(Minimum, Maximum) );
+	m_Parameters.Set_Parameter("METRIC_ZRANGE" + Suffix + ".MIN", Minimum);
+	m_Parameters.Set_Parameter("METRIC_ZRANGE" + Suffix + ".MAX", Maximum);
+
+	pClassify->Set_Metric(
+		m_Parameters("METRIC_SCALE_MODE")->asInt   (),
+		m_Parameters("METRIC_SCALE_LOG" )->asDouble(),
+		Minimum, Maximum
+	);
+
+	return( true );
 }
 
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1203,7 +1102,7 @@ bool CWKSP_Grids::Get_Image_Legend(wxBitmap &BMP, double Zoom)
 //---------------------------------------------------------
 void CWKSP_Grids::On_Draw(CWKSP_Map_DC &dc_Map, int Flags)
 {
-	if( Get_Grids()->Get_NZ() < 1 || Get_Extent().Intersects(dc_Map.m_rWorld) == INTERSECTION_None )
+	if( Get_Grid() == NULL || Get_Grids()->Get_NZ() < 1 || Get_Extent().Intersects(dc_Map.m_rWorld) == INTERSECTION_None )
 	{
 		return;
 	}
@@ -1281,7 +1180,7 @@ void CWKSP_Grids::_Draw_Grid_Nodes(CWKSP_Map_DC &dc_Map, TSG_Grid_Resampling Res
 	int	byDC	= (int)dc_Map.yWorld2DC(rMap.Get_YMax());	if( byDC < 0 )	byDC	= 0;
 	int	nyDC	= abs(ayDC - byDC);
 
-	bool	bBandWise	= m_Parameters("OVERLAY_STATISTICS")->asInt() != 0;	// bandwise statistics
+	bool	bBandWise	= m_Parameters("OVERLAY_FIT")->asInt() != 0;	// bandwise statistics
 
 	#pragma omp parallel for
 	for(int iyDC=0; iyDC<=nyDC; iyDC++)
@@ -1348,7 +1247,7 @@ void CWKSP_Grids::_Draw_Grid_Nodes(CWKSP_Map_DC &dc_Map, TSG_Grid_Resampling Res
 //---------------------------------------------------------
 void CWKSP_Grids::_Draw_Grid_Cells(CWKSP_Map_DC &dc_Map)
 {
-	bool	bBandWise	= m_Parameters("OVERLAY_STATISTICS")->asInt() != 0;	// bandwise statistics
+	bool	bBandWise	= m_Parameters("OVERLAY_FIT")->asInt() != 0;	// bandwise statistics
 
 	CSG_Grid	*pBands[3];
 
