@@ -200,7 +200,7 @@ CWKSP_Map::CWKSP_Map(void)
 	m_pLayout_Info	= new CVIEW_Layout_Info(this);
 
 	m_Img_bSave		= false;
-	m_Sync_bLock	= false;
+	m_Sync_bLock	= 0;
 
 	On_Create_Parameters();
 }
@@ -413,6 +413,12 @@ void CWKSP_Map::On_Create_Parameters(void)
 		false
 	);
 
+	m_Parameters.Add_Bool("NODE_GENERAL",
+		"CRS_CHECK"		, _TL("CRS Check"),
+		_TL("Perform a coordinate system compatibility check before a layer is added."),
+		g_pMaps->Get_Parameter("CRS_CHECK")->asBool()
+	);
+
 	//-----------------------------------------------------
 	m_Parameters.Add_Bool("NODE_GENERAL",
 		"GCS_POSITION"	, _TL("Position as Geographic Coordinates"),
@@ -565,18 +571,13 @@ void CWKSP_Map::On_Create_Parameters(void)
 		2, 1, true
 	);
 
-	m_Parameters.Add_Node("NODE_PRINT",
-		"NODE_PRINT_FRAME"	, _TL("Frame"),
-		_TL("")
-	);
-
-	m_Parameters.Add_Bool("NODE_PRINT_FRAME",
-		"PRINT_FRAME_SHOW"	, _TL("Show"),
+	m_Parameters.Add_Bool("NODE_PRINT",
+		"PRINT_FRAME_SHOW"	, _TL("Frame"),
 		_TL(""),
 		true
 	);
 
-	m_Parameters.Add_Int("NODE_PRINT_FRAME",
+	m_Parameters.Add_Int("PRINT_FRAME_SHOW",
 		"PRINT_FRAME_WIDTH"	, _TL("Width"),
 		_TL(""),
 		7, 5, true
@@ -670,33 +671,38 @@ int CWKSP_Map::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *
 	{
 		if(	pParameter->Cmp_Identifier("SEL_EXTENT") )
 		{
-			pParameters->Get_Parameter("SEL_COLOUR"    )->Set_Enabled(pParameter->asBool());
-			pParameters->Get_Parameter("SEL_TRANSP"    )->Set_Enabled(pParameter->asBool());
+			pParameters->Set_Enabled("SEL_COLOUR"       , pParameter->asBool());
+			pParameters->Set_Enabled("SEL_TRANSP"       , pParameter->asBool());
 		}
 
 		if(	pParameter->Cmp_Identifier("FRAME_SHOW") )
 		{
-			pParameters->Get_Parameter("FRAME_WIDTH"   )->Set_Enabled(pParameter->asBool());
+			pParameters->Set_Enabled("FRAME_WIDTH"      , pParameter->asBool());
 		}
 
 		if(	pParameter->Cmp_Identifier("NORTH_SHOW") )
 		{
-			pParameters->Get_Parameter("NORTH_ANGLE"   )->Set_Enabled(pParameter->asBool());
-			pParameters->Get_Parameter("NORTH_SIZE"    )->Set_Enabled(pParameter->asBool());
-			pParameters->Get_Parameter("NORTH_OFFSET_X")->Set_Enabled(pParameter->asBool());
-			pParameters->Get_Parameter("NORTH_OFFSET_Y")->Set_Enabled(pParameter->asBool());
-			pParameters->Get_Parameter("NORTH_EXTENT"  )->Set_Enabled(pParameter->asBool());
+			pParameters->Set_Enabled("NORTH_ANGLE"      , pParameter->asBool());
+			pParameters->Set_Enabled("NORTH_SIZE"       , pParameter->asBool());
+			pParameters->Set_Enabled("NORTH_OFFSET_X"   , pParameter->asBool());
+			pParameters->Set_Enabled("NORTH_OFFSET_Y"   , pParameter->asBool());
+			pParameters->Set_Enabled("NORTH_EXTENT"     , pParameter->asBool());
 		}
 
 		if(	pParameter->Cmp_Identifier("SCALE_SHOW") )
 		{
-			pParameters->Get_Parameter("SCALE_STYLE"   )->Set_Enabled(pParameter->asBool());
-			pParameters->Get_Parameter("SCALE_UNIT"    )->Set_Enabled(pParameter->asBool());
-			pParameters->Get_Parameter("SCALE_WIDTH"   )->Set_Enabled(pParameter->asBool());
-			pParameters->Get_Parameter("SCALE_HEIGHT"  )->Set_Enabled(pParameter->asBool());
-			pParameters->Get_Parameter("SCALE_OFFSET_X")->Set_Enabled(pParameter->asBool());
-			pParameters->Get_Parameter("SCALE_OFFSET_Y")->Set_Enabled(pParameter->asBool());
-			pParameters->Get_Parameter("SCALE_EXTENT"  )->Set_Enabled(pParameter->asBool());
+			pParameters->Set_Enabled("SCALE_STYLE"      , pParameter->asBool());
+			pParameters->Set_Enabled("SCALE_UNIT"       , pParameter->asBool());
+			pParameters->Set_Enabled("SCALE_WIDTH"      , pParameter->asBool());
+			pParameters->Set_Enabled("SCALE_HEIGHT"     , pParameter->asBool());
+			pParameters->Set_Enabled("SCALE_OFFSET_X"   , pParameter->asBool());
+			pParameters->Set_Enabled("SCALE_OFFSET_Y"   , pParameter->asBool());
+			pParameters->Set_Enabled("SCALE_EXTENT"     , pParameter->asBool());
+		}
+
+		if(	pParameter->Cmp_Identifier("PRINT_FRAME_SHOW") )
+		{
+			pParameters->Set_Enabled("PRINT_FRAME_WIDTH", pParameter->asBool());
 		}
 	}
 
@@ -791,47 +797,66 @@ CWKSP_Map_Layer * CWKSP_Map::Find_Layer(CWKSP_Layer *pLayer)
 //---------------------------------------------------------
 CWKSP_Map_Layer * CWKSP_Map::Add_Layer(CWKSP_Layer *pLayer)
 {
-	if( Get_Layer(pLayer) < 0 )
+	if( Get_Layer(pLayer) >= 0 )	// don't load a layer more than once
 	{
-		if( Get_Count() == 0 || (m_Parameters("GOTO_NEWLAYER")->asBool() && pLayer->Get_Object()->is_Valid()) )
-		{
-			switch( pLayer->Get_Object()->Get_ObjectType() )
-			{
-			case SG_DATAOBJECT_TYPE_Shapes:
-			case SG_DATAOBJECT_TYPE_PointCloud:
-			case SG_DATAOBJECT_TYPE_TIN:
-				if( ((CSG_Table *)pLayer->Get_Object())->Get_Count() <= 0 )
-				{
-					break;
-				}
-
-			default:
-				Set_Extent(pLayer->Get_Extent());
-				break;
-			}
-		}
-
-		if( Get_Count() == 0 )
-		{
-			m_Parameters("NAME")->Set_Value(pLayer->Get_Name().wx_str());
-
-			Parameters_Changed();
-		}
-
-		CWKSP_Map_Layer	*pItem	= new CWKSP_Map_Layer(pLayer);
-
-		Add_Item(pItem);
-		Move_Top(pItem);
-
-		if( !m_Projection.is_Okay() && pLayer->Get_Object()->Get_Projection().is_Okay() )
-		{
-			m_Projection	= pLayer->Get_Object()->Get_Projection();
-		}
-
-		return( pItem );
+		return( NULL );
 	}
 
-	return( NULL );
+	if( m_Parameters("CRS_CHECK")->asBool()
+	&&  m_Projection.is_Okay() && pLayer->Get_Object()->Get_Projection().is_Okay()
+	&&  m_Projection.is_Equal(    pLayer->Get_Object()->Get_Projection()) == false )
+	{
+		wxString	msg;
+
+		msg	+= _TL("The coordinate system used by the layer is not identical with the one of the map!");
+		msg	+= "\n";
+		msg	+= wxString::Format("\n%s:\n  [%s]", _TL("Map"  ),                         m_Projection  .Get_Proj4().c_str());
+		msg	+= wxString::Format("\n%s:\n  [%s]", _TL("Layer"), pLayer->Get_Object()->Get_Projection().Get_Proj4().c_str());
+		msg	+= "\n\n";
+		msg	+= _TL("Do you really want to proceed?");
+
+		if( DLG_Message_Confirm(msg, _TL("Add Layer to Map")) == false )
+		{
+			return( NULL );
+		}
+	}
+
+	if( Get_Count() == 0 || (m_Parameters("GOTO_NEWLAYER")->asBool() && pLayer->Get_Object()->is_Valid()) )
+	{
+		switch( pLayer->Get_Object()->Get_ObjectType() )
+		{
+		case SG_DATAOBJECT_TYPE_Shapes    :
+		case SG_DATAOBJECT_TYPE_PointCloud:
+		case SG_DATAOBJECT_TYPE_TIN       :
+			if( ((CSG_Table *)pLayer->Get_Object())->Get_Count() <= 0 )
+			{
+				break;
+			}
+
+		default:
+			Set_Extent(pLayer->Get_Extent());
+			break;
+		}
+	}
+
+	if( Get_Count() == 0 )
+	{
+		m_Parameters("NAME")->Set_Value(pLayer->Get_Name().wx_str());
+
+		Parameters_Changed();
+	}
+
+	CWKSP_Map_Layer	*pItem	= new CWKSP_Map_Layer(pLayer);
+
+	Add_Item(pItem);
+	Move_Top(pItem);
+
+	if( !m_Projection.is_Okay() && pLayer->Get_Object()->Get_Projection().is_Okay() )
+	{
+		m_Projection	= pLayer->Get_Object()->Get_Projection();
+	}
+
+	return( pItem );
 }
 
 //---------------------------------------------------------
@@ -1113,7 +1138,14 @@ void CWKSP_Map::Set_Synchronising(bool bOn)
 
 void CWKSP_Map::Lock_Synchronising(bool bOn)
 {
-	m_Sync_bLock	= bOn;
+	if( bOn )
+	{
+		m_Sync_bLock++;
+	}
+	else if( m_Sync_bLock > 0 )
+	{
+		m_Sync_bLock--;
+	}
 }
 
 //---------------------------------------------------------
@@ -1171,21 +1203,15 @@ void CWKSP_Map::Set_CrossHair(const TSG_Point &Point, const CSG_Projection &Proj
 {
 	if( m_pView )
 	{
-		if( !Projection.is_Okay() )
+		TSG_Point	p;
+
+		if( !Projection.is_Okay() || !m_Projection.is_Okay() || Projection == m_Projection )
 		{
 			m_pView->Get_Map_Control()->Set_CrossHair(Point);
 		}
-		else if( m_Projection.is_Okay() )
+		else if( SG_Get_Projected(Projection, m_Projection, p = Point) )
 		{
-			TSG_Point	p	= Point;
-
-			if( SG_Get_Projected(Projection, m_Projection, p) )
-			{
-				if( m_pView )
-				{
-					m_pView->Get_Map_Control()->Set_CrossHair(p);
-				}
-			}
+			m_pView->Get_Map_Control()->Set_CrossHair(p);
 		}
 	}
 }
@@ -1207,24 +1233,21 @@ void CWKSP_Map::Set_CrossHair_Off(void)
 //---------------------------------------------------------
 void CWKSP_Map::Set_Projection(void)
 {
-	CSG_Tool	*pTool	= SG_Get_Tool_Library_Manager().Get_Tool("pj_proj4", 15);	// CCRS_Picker
+	CSG_Tool	*pTool	= SG_Get_Tool_Library_Manager().Create_Tool("pj_proj4", 15);	// CCRS_Picker
 
-	if(	pTool )
+	if(	pTool && pTool->Get_Parameters()->Set_Parameter("CRS_PROJ4", m_Projection.Get_Proj4())
+	&&	pTool->On_Before_Execution() && DLG_Parameters(pTool->Get_Parameters()) )
 	{
-		pTool->Settings_Push();
+		pTool->Set_Manager(NULL);
 
-		if( pTool->Get_Parameters()->Set_Parameter("CRS_PROJ4", m_Projection.Get_Proj4())
-		&&	pTool->On_Before_Execution() && DLG_Parameters(pTool->Get_Parameters()) )
-		{
-			pTool->Execute();
+		pTool->Execute();
 
-			m_Projection.Assign((*pTool->Get_Parameters())("CRS_PROJ4")->asString(), SG_PROJ_FMT_Proj4);
+		m_Projection.Create(pTool->Get_Parameter("CRS_PROJ4")->asString(), SG_PROJ_FMT_Proj4);
 
-			View_Refresh(false);
-		}
-
-		pTool->Settings_Pop();
+		View_Refresh(false);
 	}
+
+	SG_Get_Tool_Library_Manager().Delete_Tool(pTool);
 }
 
 
@@ -1442,9 +1465,10 @@ void CWKSP_Map::SaveAs_Image_Clipboard(bool bLegend)
 	if( bLegend == false )
 	{
 		SaveAs_Image_Clipboard(
-			Get_Manager()->Get_Parameter("CLIP_NX"   )->asInt(),
-			Get_Manager()->Get_Parameter("CLIP_NY"   )->asInt(),
-			Get_Manager()->Get_Parameter("CLIP_FRAME")->asInt()
+			Get_Manager()->Get_Parameter("CLIP_NX")->asInt(),
+			Get_Manager()->Get_Parameter("CLIP_NY")->asInt(),
+			Get_Manager()->Get_Parameter("CLIP_FRAME_SHOW")->asBool() ?
+			Get_Manager()->Get_Parameter("CLIP_FRAME_WIDTH")->asInt() : 0
 		);
 
 		return;
@@ -1586,7 +1610,7 @@ void CWKSP_Map::SaveAs_Image_To_KMZ(int nx, int ny)
 	CSG_Grid	Map(SG_DATATYPE_Int, Image.GetWidth(), Image.GetHeight(), Extent.Get_XRange() / (double)Image.GetWidth(), Extent.Get_XMin(), Extent.Get_YMin());
 
 	Map.Set_Name(Get_Name().wx_str());
-	Map.Set_NoData_Value(16711935);
+	Map.Set_NoData_Value(SG_GET_RGB(MASK_R, MASK_G, MASK_B));
 	Map.Get_Projection().Create(m_Projection);
 
 	for(int y=0, yy=Map.Get_NY()-1; y<Map.Get_NY(); y++, yy--)
@@ -1654,7 +1678,7 @@ void CWKSP_Map::SaveAs_Image_To_Memory(int nx, int ny)
 
 		if( P("COLORS_TYPE") )
 		{
-			P("COLORS_TYPE")->Set_Value(4);	// Color Classification Type: RGB Coded Values
+			P("COLORS_TYPE")->Set_Value(5);	// Color Classification Type: RGB Coded Values
 
 			g_pData->Set_Parameters(pGrid, &P);
 		}
