@@ -24,7 +24,8 @@
 // Geoscientific Analyses'. SAGA is free software; you   //
 // can redistribute it and/or modify it under the terms  //
 // of the GNU General Public License as published by the //
-// Free Software Foundation; version 2 of the License.   //
+// Free Software Foundation, either version 2 of the     //
+// License, or (at your option) any later version.       //
 //                                                       //
 // SAGA is distributed in the hope that it will be       //
 // useful, but WITHOUT ANY WARRANTY; without even the    //
@@ -33,10 +34,8 @@
 // License for more details.                             //
 //                                                       //
 // You should have received a copy of the GNU General    //
-// Public License along with this program; if not,       //
-// write to the Free Software Foundation, Inc.,          //
-// 51 Franklin Street, 5th Floor, Boston, MA 02110-1301, //
-// USA.                                                  //
+// Public License along with this program; if not, see   //
+// <http://www.gnu.org/licenses/>.                       //
 //                                                       //
 //-------------------------------------------------------//
 //                                                       //
@@ -74,6 +73,7 @@
 #include "wksp_map_layer.h"
 
 #include "wksp_grid.h"
+#include "wksp_grids.h"
 
 
 ///////////////////////////////////////////////////////////
@@ -95,14 +95,12 @@ CWKSP_Map_Layer::CWKSP_Map_Layer(CWKSP_Layer *pLayer)
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 wxString CWKSP_Map_Layer::Get_Name(void)
 {
-	return( m_bShow ? m_pLayer->Get_Name() : wxString::Format(wxT("[%s]"), m_pLayer->Get_Name().c_str()) );
+	return( m_bShow ? m_pLayer->Get_Name() : wxString::Format("[%s]", m_pLayer->Get_Name().c_str()) );
 }
 
 //---------------------------------------------------------
@@ -132,6 +130,7 @@ wxMenu * CWKSP_Map_Layer::Get_Menu(void)
 		break;
 
 	case WKSP_ITEM_Grid:
+	case WKSP_ITEM_Grids:
 		pMenu->AppendSeparator();
 		CMD_Menu_Add_Item(pMenu, true, ID_CMD_MAPS_GRID_FITCOLORS);
 		break;
@@ -149,8 +148,6 @@ wxMenu * CWKSP_Map_Layer::Get_Menu(void)
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -252,8 +249,6 @@ bool CWKSP_Map_Layer::On_Command_UI(wxUpdateUIEvent &event)
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -273,15 +268,13 @@ void CWKSP_Map_Layer::Parameters_Changed(void)
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 #define	FIT_OVERLAY_GRID_COLORS(band, extent)	{\
 	CWKSP_Grid	*pGrid	= (CWKSP_Grid *)g_pData->Get(m_pLayer->Get_Parameter(band)->asGrid());\
 	if( pGrid && m_pLayer->Get_Parameter(band)->is_Enabled() )\
-	{	pGrid->Fit_Color_Range(extent);	}\
+	{	pGrid->Fit_Colors(extent);	}\
 }
 
 //---------------------------------------------------------
@@ -289,9 +282,13 @@ bool CWKSP_Map_Layer::Fit_Colors(const CSG_Rect &rWorld)
 {
 	if( m_bFitColors )
 	{
-		if( m_pLayer->Get_Type() == WKSP_ITEM_Grid )
+		switch( m_pLayer->Get_Type() )
 		{
-			((CWKSP_Grid *)m_pLayer)->Fit_Color_Range(rWorld);
+		default:
+			return( false );
+
+		case WKSP_ITEM_Grid :
+			((CWKSP_Grid  *)m_pLayer)->Fit_Colors(rWorld);
 
 			if( m_pLayer->Get_Parameter("COLORS_TYPE")->asInt() == CLASSIFY_OVERLAY )
 			{
@@ -299,9 +296,14 @@ bool CWKSP_Map_Layer::Fit_Colors(const CSG_Rect &rWorld)
 				FIT_OVERLAY_GRID_COLORS("OVERLAY_G", rWorld);
 				FIT_OVERLAY_GRID_COLORS("OVERLAY_B", rWorld);
 			}
+			break;
 
-			return( true );
+		case WKSP_ITEM_Grids:
+			((CWKSP_Grids *)m_pLayer)->Fit_Colors(rWorld);
+			break;
 		}
+
+		return( true );
 	}
 
 	return( false );
