@@ -116,8 +116,6 @@ CWKSP_PointCloud::~CWKSP_PointCloud(void)
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -214,8 +212,6 @@ wxMenu * CWKSP_PointCloud::Get_Menu(void)
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -315,8 +311,6 @@ bool CWKSP_PointCloud::On_Command_UI(wxUpdateUIEvent &event)
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -326,7 +320,7 @@ void CWKSP_PointCloud::On_Create_Parameters(void)
 
 	//-----------------------------------------------------
 	m_Parameters.Add_Int("NODE_DISPLAY",
-		"DISPLAY_SIZE"			, _TL("Point Size"),
+		"DISPLAY_SIZE"	, _TL("Point Size"),
 		_TL(""),
 		0, 0, true
 	);
@@ -360,12 +354,25 @@ void CWKSP_PointCloud::On_Create_Parameters(void)
 //---------------------------------------------------------
 void CWKSP_PointCloud::On_DataObject_Changed(void)
 {
-	CWKSP_Layer::On_DataObject_Changed();
+	{
+		if( m_fValue >= Get_PointCloud()->Get_Field_Count() )
+		{
+			m_fValue	= Get_PointCloud()->Get_Field_Count() - 1;
+		}
+
+		double	m	= Get_PointCloud()->Get_Mean  (m_fValue);
+		double	s	= Get_PointCloud()->Get_StdDev(m_fValue) * 2.0;
+
+		m_Parameters("METRIC_ZRANGE")->asRange()->Set_Range(m - s, m + s);
+	}
 
 	_AttributeList_Set(m_Parameters("LUT_ATTRIB"   ), false);
 	_AttributeList_Set(m_Parameters("METRIC_ATTRIB"), false);
 	_AttributeList_Set(m_Parameters("RGB_ATTRIB"   ), false);
 
+	//-----------------------------------------------------
+	CWKSP_Layer::On_DataObject_Changed();
+
 	m_pTable->DataObject_Changed();
 }
 
@@ -377,11 +384,11 @@ void CWKSP_PointCloud::On_Parameters_Changed(void)
 	//-----------------------------------------------------
 	switch( m_Parameters("COLORS_TYPE")->asInt() )
 	{
-	default:	m_fValue	= -1;										break;	// CLASSIFY_UNIQUE
-	case  1:	m_fValue	= m_Parameters("LUT_ATTRIB"   )->asInt();	break;	// CLASSIFY_LUT
-	case  2:	m_fValue	= m_Parameters("METRIC_ATTRIB")->asInt();	break;	// CLASSIFY_METRIC
-	case  3:	m_fValue	= m_Parameters("METRIC_ATTRIB")->asInt();	break;	// CLASSIFY_GRADUATED
-	case  4:	m_fValue	= m_Parameters("RGB_ATTRIB"   )->asInt();	break;	// CLASSIFY_RGB
+	default: m_fValue = -1                                    ; break;	// CLASSIFY_UNIQUE
+	case  1: m_fValue = m_Parameters("LUT_ATTRIB"   )->asInt(); break;	// CLASSIFY_LUT
+	case  2: m_fValue = m_Parameters("METRIC_ATTRIB")->asInt(); break;	// CLASSIFY_METRIC
+	case  3: m_fValue = m_Parameters("METRIC_ATTRIB")->asInt(); break;	// CLASSIFY_GRADUATED
+	case  4: m_fValue = m_Parameters("RGB_ATTRIB"   )->asInt(); break;	// CLASSIFY_RGB
 	}
 
 	if( m_fValue < 0 || m_fValue >= Get_PointCloud()->Get_Field_Count() )
@@ -390,7 +397,7 @@ void CWKSP_PointCloud::On_Parameters_Changed(void)
 
 		m_pClassify->Set_Mode(CLASSIFY_UNIQUE);
 	}
-	else if( m_Parameters("COLORS_TYPE")->asInt() == 4 )
+	else if( m_Parameters("COLORS_TYPE")->asInt() == CLASSIFY_OVERLAY )
 	{
 		m_pClassify->Set_Mode(CLASSIFY_RGB);
 	}
@@ -399,7 +406,13 @@ void CWKSP_PointCloud::On_Parameters_Changed(void)
 	long	DefColor	= m_Parameters("UNISYMBOL_COLOR")->asColor();
 	m_Color_Pen			= wxColour(SG_GET_R(DefColor), SG_GET_G(DefColor), SG_GET_B(DefColor));
 
-	m_PointSize			= m_Parameters("DISPLAY_SIZE")	->asInt();
+	m_PointSize			= m_Parameters("DISPLAY_SIZE")->asInt();
+}
+
+//---------------------------------------------------------
+void CWKSP_PointCloud::On_Update_Views(void)
+{
+	m_pTable->Update_Views();
 }
 
 
@@ -446,28 +459,6 @@ int CWKSP_PointCloud::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Para
 	return( CWKSP_Layer::On_Parameter_Changed(pParameters, pParameter, Flags) );
 }
 
-//---------------------------------------------------------
-void CWKSP_PointCloud::On_Update_Views(void)
-{
-	m_pTable->Update_Views();
-}
-
-//---------------------------------------------------------
-bool CWKSP_PointCloud::Fit_Colors(void)
-{
-	if( m_fValue >= Get_PointCloud()->Get_Field_Count() )
-	{
-		m_fValue	= Get_PointCloud()->Get_Field_Count() - 1;
-	}
-
-	double	m	= Get_PointCloud()->Get_Mean  (m_fValue);
-	double	s	= Get_PointCloud()->Get_StdDev(m_fValue) * 2.0;
-
-	m_Parameters("METRIC_ZRANGE")->asRange()->Set_Range(m - s, m + s);
-
-	return( true );
-}
-
 
 ///////////////////////////////////////////////////////////
 //														 //
@@ -479,42 +470,30 @@ wxString CWKSP_PointCloud::Get_Name_Attribute(void)
 	return(	m_fValue < 0 || m_pClassify->Get_Mode() == CLASSIFY_UNIQUE ? SG_T("") : Get_PointCloud()->Get_Field_Name(m_fValue) );
 }
 
-//---------------------------------------------------------
-CSG_Parameter * CWKSP_PointCloud::_AttributeList_Add(CSG_Parameter *pNode, const CSG_String &Identifier, const CSG_String &Name, const CSG_String &Description)
-{
-	CSG_Parameter *pParameter;
-
-	pParameter	= m_Parameters.Add_Choice(
-		pNode, Identifier, Name, Description,
-		CSG_String::Format(SG_T("%s|"), _TL("<default>")), 0
-	);
-
-	return( pParameter );
-}
-
 //---------------------------------------------------------
 void CWKSP_PointCloud::_AttributeList_Set(CSG_Parameter *pFields, bool bAddNoField)
 {
 	if( pFields && pFields->Get_Type() == PARAMETER_TYPE_Choice )
 	{
-		wxString	s;
+		CSG_String	s;
 
 		for(int i=0; i<Get_PointCloud()->Get_Field_Count(); i++)
 		{
-			s.Append(wxString::Format("%s|", Get_PointCloud()->Get_Field_Name(i)));
+			s	+= Get_PointCloud()->Get_Field_Name(i); s += "|";
 		}
 
 		if( bAddNoField )
 		{
-			s.Append(wxString::Format("%s|", _TL("<none>")));
-		}
+			s	+= _TL("<none>");
 
-		pFields->asChoice()->Set_Items(s);
+			pFields->asChoice()->Set_Items(s);
 
-		if( bAddNoField )
-		{
 			pFields->Set_Value(Get_PointCloud()->Get_Field_Count());
 		}
+		else
+		{
+			pFields->asChoice()->Set_Items(s);
+		}
 	}
 }
 
@@ -543,7 +522,7 @@ void CWKSP_PointCloud::_LUT_Create(void)
 		Parameters.Add_Choice("", "FIELD" , _TL("Attribute"     ), _TL(""), "");
 		Parameters.Add_Colors("", "COLOR" , _TL("Colors"        ), _TL(""))->asColors()->Set_Count(11);
 		Parameters.Add_Choice("", "METHOD", _TL("Classification"), _TL(""),
-			CSG_String::Format("%s|%s|%s|%s|",
+			CSG_String::Format("%s|%s|%s|%s",
 				_TL("unique values"),
 				_TL("equal intervals"),
 				_TL("quantiles"),
