@@ -161,7 +161,7 @@ CShapes_Save::CShapes_Save(void)
 	Parameters.Add_Choice(NULL,
 		"EXISTS"	, _TL("If table exists..."),
 		_TL(""),
-		CSG_String::Format("%s|%s|%s|",
+		CSG_String::Format("%s|%s|%s",
 			_TL("abort export"),
 			_TL("replace existing table"),
 			_TL("append records, if table structure allows")
@@ -174,16 +174,25 @@ CShapes_Save::CShapes_Save(void)
 //---------------------------------------------------------
 int CShapes_Save::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
+	if( pParameter->Cmp_Identifier("NAME") )
+	{
+		pParameter->Set_Value(CSG_PG_Connection::Make_Table_Name(pParameter->asString()));
+	}
+
 	if( pParameter->Cmp_Identifier("SHAPES") )
 	{
-		CSG_Shapes	*pShapes	= pParameter->asShapes() ? pParameter->asShapes() : NULL;
-
-		if( pShapes && *pShapes->Get_Name() )
+		if( pParameter->asShapes() )
 		{
-			pParameters->Get_Parameter("NAME")->Set_Value(pShapes->Get_Name());
-		}
+			pParameters->Set_Parameter("NAME", CSG_PG_Connection::Make_Table_Name(pParameter->asShapes()->Get_Name()));
 
-		Set_SRID(pParameters, pShapes ? pShapes->Get_Projection().Get_EPSG() : -1);
+			Set_SRID(pParameters, pParameter->asShapes()->Get_Projection().Get_EPSG());
+		}
+		else
+		{
+			pParameters->Set_Parameter("NAME", "");
+
+			Set_SRID(pParameters, -1);
+		}
 	}
 
 	return( CSG_PG_Tool::On_Parameter_Changed(pParameters, pParameter) );
@@ -288,7 +297,7 @@ bool CShapes_Save::On_Execute(void)
 
 	for(iField=0; iField<pShapes->Get_Field_Count(); iField++)
 	{
-		Insert	+= CSG_String(", ") + pShapes->Get_Field_Name(iField);
+		Insert	+= CSG_String(", ") + CSG_PG_Connection::Make_Table_Field_Name(pShapes, iField);
 	}
 
 	Insert	+= ") VALUES (";
