@@ -171,7 +171,7 @@ void CGrid_Merge::Add_Parameters(CSG_Parameters &Parameters)
 //---------------------------------------------------------
 int CGrid_Merge::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
-	if( !SG_STR_CMP(pParameter->Get_Identifier(), "GRIDS") )
+	if( pParameter->Cmp_Identifier("GRIDS") )
 	{
 		Set_Target(pParameters, pParameter->asList(), m_Grid_Target);
 	}
@@ -182,7 +182,7 @@ int CGrid_Merge::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter
 //---------------------------------------------------------
 int CGrid_Merge::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
-	if(	!SG_STR_CMP(pParameter->Get_Identifier(), "OVERLAP") )
+	if(	pParameter->Cmp_Identifier("OVERLAP") )
 	{
 		pParameters->Set_Enabled("BLEND_DIST", pParameter->asInt() == 5 || pParameter->asInt() == 6);
 	}
@@ -219,7 +219,7 @@ bool CGrid_Merge::On_Execute(void)
 		//-------------------------------------------------
 		if(	is_Aligned(pGrid) )
 		{
-			Process_Set_Text(CSG_String::Format("[%d/%d] %s: %s", i + 1, m_pGrids->Get_Grid_Count(), _TL("copying"), pGrid->Get_Name()));
+			Process_Set_Text("[%d/%d] %s: %s", i + 1, m_pGrids->Get_Grid_Count(), _TL("copying"), pGrid->Get_Name());
 
 			int	nx	= pGrid->Get_NX(); if( nx > m_pMosaic->Get_NX() - ax )	nx	= m_pMosaic->Get_NX() - ax;
 			int	ny	= pGrid->Get_NY(); if( ny > m_pMosaic->Get_NY() - ay )	ny	= m_pMosaic->Get_NY() - ay;
@@ -243,7 +243,7 @@ bool CGrid_Merge::On_Execute(void)
 		//-------------------------------------------------
 		else
 		{
-			Process_Set_Text(CSG_String::Format("[%d/%d] %s: %s", i + 1, m_pGrids->Get_Grid_Count(), _TL("resampling"), pGrid->Get_Name()));
+			Process_Set_Text("[%d/%d] %s: %s", i + 1, m_pGrids->Get_Grid_Count(), _TL("resampling"), pGrid->Get_Name());
 
 			if( ax < 0 )	ax	= 0;
 			if( ay < 0 )	ay	= 0;
@@ -708,7 +708,7 @@ void CGrid_Merge::Get_Match(CSG_Grid *pGrid)
 		//-------------------------------------------------
 		else	// investigate overlapping areas
 		{
-			Process_Set_Text(CSG_String::Format("%s: %s", _TL("analyzing overlap"), pGrid->Get_Name()));
+			Process_Set_Text("%s: %s", _TL("analyzing overlap"), pGrid->Get_Name());
 
 			int	ax	= (int)((pGrid->Get_XMin() - m_pMosaic->Get_XMin()) / m_pMosaic->Get_Cellsize());	if( ax < 0 )	ax	= 0;
 			int	ay	= (int)((pGrid->Get_YMin() - m_pMosaic->Get_YMin()) / m_pMosaic->Get_Cellsize());	if( ay < 0 )	ay	= 0;
@@ -821,7 +821,7 @@ CGrids_Merge::CGrids_Merge(void)
 //---------------------------------------------------------
 int CGrids_Merge::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
-	if( !SG_STR_CMP(pParameter->Get_Identifier(), "GRIDS") )
+	if( pParameter->Cmp_Identifier("GRIDS") )
 	{
 		CGrid_Merge::Set_Target(pParameters, pParameter->asList(), m_Grid_Target);
 	}
@@ -832,7 +832,7 @@ int CGrids_Merge::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Paramete
 //---------------------------------------------------------
 int CGrids_Merge::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
-	if(	!SG_STR_CMP(pParameter->Get_Identifier(), "OVERLAP") )
+	if(	pParameter->Cmp_Identifier("OVERLAP") )
 	{
 		pParameters->Set_Enabled("BLEND_DIST", pParameter->asInt() == 5 || pParameter->asInt() == 6);
 	}
@@ -881,9 +881,9 @@ bool CGrids_Merge::On_Execute(void)
 
 	Mosaic.Set_Manager(NULL);
 	Mosaic.Get_Parameters()->Assign_Values(&Parameters);
-	Mosaic.Get_Parameters()->Get("TARGET_DEFINITION")->Set_Value(1);	// grid or grid system
+	Mosaic.Set_Parameter("TARGET_DEFINITION", 1);	// grid or grid system
 
-	CSG_Parameter_Grid_List	*pList_Grid	= Mosaic.Get_Parameters()->Get("GRIDS")->asGridList();
+	CSG_Parameter_Grid_List	*pList_Grid	= (*Mosaic.Get_Parameters())("GRIDS")->asGridList();
 
 	for(int z=0; z<pGrids->Get_NZ(); z++)
 	{
@@ -897,13 +897,13 @@ bool CGrids_Merge::On_Execute(void)
 			}
 			else if( z == pList_Grids->Get_Grids(i)->Get_NZ() )	// throw warning only once
 			{
-				Message_Add(CSG_String::Format("[%s] %s: [%d] %s", _TL("Warning"), _TL("incompatible input"), i + 1, pList_Grids->Get_Grids(i)->Get_Name()));
+				Message_Fmt("\n[%s] %s: [%d] %s", _TL("Warning"), _TL("incompatible input"), i + 1, pList_Grids->Get_Grids(i)->Get_Name());
 			}
 		}
 
 		pMosaic->Get_Attributes(z).Assign(&pGrids->Get_Attributes(z));
 
-		Mosaic.Get_Parameters()->Get("TARGET_OUT_GRID")->Set_Value(pMosaic->Get_Grid_Ptr(z));
+		Mosaic.Get_Parameters()->Set_Parameter("TARGET_OUT_GRID", (void *)pMosaic->Get_Grid_Ptr(z));
 
 		if( !Mosaic.Execute() )
 		{
