@@ -97,7 +97,7 @@ class pj_proj4_EXPORT CPROJ4_Base : public CSG_Tool
 public:
 	CPROJ4_Base(int Interface, bool bInputList);
 
-	virtual bool		do_Sync_Projections			(void)	{	return( false  );	}
+	virtual bool		do_Sync_Projections			(void)	const	{	return( false );	}
 
 
 protected:
