@@ -80,21 +80,18 @@ extern "C" {
 //---------------------------------------------------------
 CCRS_Base::CCRS_Base(void)
 {
-	m_Projection.Create(4326);
+	m_Projection.Create(4326);	// EPSG: GCS WGS84
 
 	//-----------------------------------------------------
-	if( SG_UI_Get_Window_Main() == NULL )
-	{
-		Parameters.Add_Choice("",
-			"CRS_METHOD"	, _TL("Get CRS Definition from..."),
-			_TL(""),
-			CSG_String::Format("%s|%s|%s|",
-				_TL("Proj4 Parameters"),
-				_TL("EPSG Code"),
-				_TL("Well Known Text File")
-			), 0
-		);
-	}
+	Parameters.Add_Choice("",
+		"CRS_METHOD"	, _TL("Get CRS Definition from..."),
+		_TL(""),
+		CSG_String::Format("%s|%s|%s",
+			_TL("Proj4 Parameters"),
+			_TL("EPSG Code"),
+			_TL("Well Known Text File")
+		), 0
+	)->Set_UseInGUI(false);
 
 	//-----------------------------------------------------
 	Parameters.Add_String("",
@@ -103,45 +100,39 @@ CCRS_Base::CCRS_Base(void)
 		m_Projection.Get_Proj4(), true
 	);
 
-	if( SG_UI_Get_Window_Main() )
-	{
-		Parameters.Add_Parameters("CRS_PROJ4",
-			"CRS_DIALOG"	, _TL("User Defined"),
-			_TL("")
-		);
-
-		Set_User_Parameters(*Parameters("CRS_DIALOG")->asParameters());
-	}
-
 	//-----------------------------------------------------
-	if( SG_UI_Get_Window_Main() )
-	{
-		Parameters.Add_Parameters("CRS_PROJ4",
-			"CRS_GRID"	, _TL("Loaded Grid")  , _TL("")
-		)->asParameters()->Add_Grid("",
-			"PICK"		, _TL("Grid"),
-			_TL(""),
-			PARAMETER_INPUT_OPTIONAL, false
-		);
+	Parameters.Add_Parameters("CRS_PROJ4",
+		"CRS_DIALOG"	, _TL("User Defined"),
+		_TL("")
+	)->Set_UseInCMD(false);
 
-		Parameters.Add_Parameters("CRS_PROJ4",
-			"CRS_SHAPES", _TL("Loaded Shapes"), _TL("")
-		)->asParameters()->Add_Shapes("",
-			"PICK"		, _TL("Shapes"),
-			_TL(""),
-			PARAMETER_INPUT_OPTIONAL
-		);
-	}
+	Set_User_Parameters(*Parameters("CRS_DIALOG")->asParameters());
+
+	Parameters.Add_Parameters("CRS_PROJ4",
+		"CRS_GRID"	, _TL("Loaded Grid")  , _TL("")
+	)->asParameters()->Add_Grid("",
+		"PICK"		, _TL("Grid"),
+		_TL(""),
+		PARAMETER_INPUT_OPTIONAL, false
+	)->Set_UseInCMD(false);
+
+	Parameters.Add_Parameters("CRS_PROJ4",
+		"CRS_SHAPES", _TL("Loaded Shapes"), _TL("")
+	)->asParameters()->Add_Shapes("",
+		"PICK"		, _TL("Shapes"),
+		_TL(""),
+		PARAMETER_INPUT_OPTIONAL
+	)->Set_UseInCMD(false);
 
 	//-----------------------------------------------------
 	Parameters.Add_FilePath("CRS_PROJ4",
 		"CRS_FILE"		, _TL("Well Known Text File"),
 		_TL(""),
-		CSG_String::Format("%s|*.prj;*.wkt;*.txt|%s|*.prj|%s|*.wkt|%s|*.txt|%s|*.*",
+		CSG_String::Format("%s|*.prj;*.wkt;*.txt|%s (*.prj)|*.prj|%s (*.wkt)|*.wkt|%s (*.txt)|*.txt|%s|*.*",
 			_TL("All Recognized Files"),
-			_TL("ESRI WKT Files (*.prj)"),
-			_TL("WKT Files (*.wkt)"),
-			_TL("Text Files (*.txt)"),
+			_TL("ESRI WKT Files"),
+			_TL("WKT Files"),
+			_TL("Text Files"),
 			_TL("All Files")
 		)
 	);
@@ -159,20 +150,17 @@ CCRS_Base::CCRS_Base(void)
 		"EPSG"
 	);
 
-	if( SG_UI_Get_Window_Main() )
-	{
-		Parameters.Add_Choice("CRS_EPSG",
-			"CRS_EPSG_GEOGCS"	, _TL("Geographic Coordinate Systems"),
-			_TL(""),
-			SG_Get_Projections().Get_Names_List(SG_PROJ_TYPE_CS_Geographic)
-		);
+	Parameters.Add_Choice("CRS_EPSG",
+		"CRS_EPSG_GEOGCS"	, _TL("Geographic Coordinate Systems"),
+		_TL(""),
+		SG_Get_Projections().Get_Names_List(SG_PROJ_TYPE_CS_Geographic)
+	)->Set_UseInCMD(false);
 
-		Parameters.Add_Choice("CRS_EPSG",
-			"CRS_EPSG_PROJCS"	, _TL("Projected Coordinate Systems"),
-			_TL(""),
-			SG_Get_Projections().Get_Names_List(SG_PROJ_TYPE_CS_Projected)
-		);
-	}
+	Parameters.Add_Choice("CRS_EPSG",
+		"CRS_EPSG_PROJCS"	, _TL("Projected Coordinate Systems"),
+		_TL(""),
+		SG_Get_Projections().Get_Names_List(SG_PROJ_TYPE_CS_Projected)
+	)->Set_UseInCMD(false);
 
 	//-----------------------------------------------------
 	Parameters.Add_Bool("",
@@ -211,10 +199,6 @@ int CCRS_Base::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *
 	{
 		Projection.Create(pParameter->asString(), SG_PROJ_FMT_Proj4);
 	}
-	else if( (*pParameters)("CRS_PROJ4") )
-	{
-		Projection.Create((*pParameters)("CRS_PROJ4")->asString(), SG_PROJ_FMT_Proj4);
-	}
 
 	//-----------------------------------------------------
 	if(	pParameter->Cmp_Identifier("CRS_DIALOG") )
@@ -231,11 +215,16 @@ int CCRS_Base::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *
 	}
 
 	//-----------------------------------------------------
-	if(	pParameter->Cmp_Identifier("CRS_EPSG") )
+	if(	pParameter->Cmp_Identifier("CRS_EPSG") || pParameter->Cmp_Identifier("CRS_EPSG_AUTH") )
 	{
-		if( !Projection.Create((*pParameters)("CRS_EPSG")->asInt()) )
+		int	Code	= (*pParameters)("CRS_EPSG")->asInt();
+
+		if( Code >= 0 )
 		{
-			SG_UI_Dlg_Message(_TL("Unknown Authority Code"), _TL("WARNING"));
+			if( !Projection.Create(Code, (*pParameters)("CRS_EPSG_AUTH")->asString()) )
+			{
+				SG_UI_Dlg_Message(_TL("Unknown Authority Code"), _TL("Warning"));
+			}
 		}
 	}
 
@@ -245,9 +234,9 @@ int CCRS_Base::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *
 	{
 		int		EPSG;
 
-		if( pParameter->asChoice()->Get_Data(EPSG) )
+		if( pParameter->asChoice()->Get_Data(EPSG) && Projection.Create(EPSG) )
 		{
-			Projection.Create(EPSG);
+			pParameters->Set_Parameter("CRS_EPSG_AUTH", "EPSG");
 		}
 	}
 
@@ -268,12 +257,9 @@ int CCRS_Base::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *
 	{
 		m_Projection	= Projection;
 
-		(*pParameters)("CRS_PROJ4")->Set_Value(m_Projection.Get_Proj4());
-
-		if( !m_Projection.Get_Authority().CmpNoCase("EPSG") )
-		{
-			(*pParameters)("CRS_EPSG")->Set_Value(m_Projection.Get_EPSG());
-		}
+		pParameters->Set_Parameter("CRS_PROJ4"    , m_Projection.Get_Proj4       ());
+		pParameters->Set_Parameter("CRS_EPSG"     , m_Projection.Get_Authority_ID());
+		pParameters->Set_Parameter("CRS_EPSG_AUTH", m_Projection.Get_Authority   ());
 
 		if( (*pParameters)("CRS_DIALOG") )
 		{
@@ -357,11 +343,11 @@ int CCRS_Base::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parameter *
 //---------------------------------------------------------
 bool CCRS_Base::Get_Projection(CSG_Projection &Projection)
 {
-	if( !Parameters("CRS_METHOD") )
+	if( SG_UI_Get_Window_Main() )	// gui? projection is also updated on parameter changed event!
 	{
 		Projection	= m_Projection;
 	}
-	else switch( Parameters("CRS_METHOD")->asInt() )
+	else switch( Parameters("CRS_METHOD")->asInt() )	// no gui? check out, how projection shall be initialized!
 	{
 	default:	// Proj4 Parameters
 		if( !Projection.Create(Parameters("CRS_PROJ4")->asString(), SG_PROJ_FMT_Proj4) )
@@ -409,7 +395,7 @@ bool CCRS_Base::Set_User_Parameters(CSG_Parameters &P)
 	P.Add_Choice("",
 		"DATUM_DEF", _TL("Datum Definition"),
 		_TL(""),
-		CSG_String::Format("%s|%s|",
+		CSG_String::Format("%s|%s",
 			_TL("Predefined Datum"),
 			_TL("User Defined Datum")
 		)
@@ -486,7 +472,7 @@ bool CCRS_Base::Set_User_Parameters(CSG_Parameters &P)
 	P.Add_Choice("DATUM_DEF",
 		"ELLIPSOID", _TL("Ellipsoid Definition"),
 		_TL(""),
-		CSG_String::Format("%s|%s|%s|%s|%s|%s|",
+		CSG_String::Format("%s|%s|%s|%s|%s|%s",
 			_TL("Predefined Ellipsoids"),
 			_TL("Semimajor Axis and Semiminor Axis"),
 			_TL("Semimajor Axis and Flattening"),
@@ -512,7 +498,7 @@ bool CCRS_Base::Set_User_Parameters(CSG_Parameters &P)
 	P.Add_Choice("DATUM_DEF",
 		"DATUM_SHIFT", _TL("Datum Shift"),
 		_TL(""),
-		CSG_String::Format("%s|%s|%s|%s|",
+		CSG_String::Format("%s|%s|%s|%s",
 			_TL("none"),
 			_TL("3 parameters (translation only)"),
 			_TL("7 parameters"),
