@@ -101,7 +101,7 @@ private:
 
 	double				m_dTime, m_Epsilon;
 
-	CSG_Grid			*m_pDEM, *m_pFlow, m_Flow_t0, *m_dFlow, m_Length, m_Alpha;
+	CSG_Grid			*m_pDEM, *m_pFlow, m_Flow_t0, m_dFlow[8], m_Length, m_Alpha;
 
 	CSG_Table			*m_pGauges_Flow;
 
